<?php



namespace WpieApp\Core\Helpers;

use WpieApp\Core\Utils\DB;

defined( 'WPIE__FILE__' ) || exit;


trait ImpExpTypes {

        private static $data = [];

        
        public static function getImpExptypes() {

                if ( isset( self::$data[ 'imp-exp-types' ] ) ) {
                        return self::$data[ 'imp-exp-types' ];
                }

                $standard = self::processImpExptypes( "standard", self::getStandardTypes() );

                $customPosts = self::processImpExptypes( "posts", self::getCustomPostTypes() );

                $customTaxonomies = self::processImpExptypes( "taxonomies", self::getSupportedTaxonomies() );

                
                self::$data[ 'imp-exp-types' ] = \apply_filters( 'Wpie/ImpExpTypes', array_merge( $standard, $customPosts, $customTaxonomies ) );

                return self::$data[ 'imp-exp-types' ];
        }

        
        public static function processImpExptypes( $prefix = '', $data = [] ) {

                return array_combine( Helper::addPrefix( array_keys( $data ), $prefix . '/' ), array_values( $data ) );
        }

        
        public static function getCustomPostTypes() {

                if ( isset( self::$data[ 'custom-posts' ] ) ) {
                        return self::$data[ 'custom-posts' ];
                }

                $basetypes = [ 'post', 'page' ];

                $postTypes = self::getPostTypes();

                //Remove Excludes Types
                $excludes = self::getExcludeTypes();

                $types = array_diff_key( $postTypes, array_flip( $basetypes ), array_flip( $excludes ) );

                $types = array_map( "ucwords", preg_replace( '/[^A-Za-z0-9]/', ' ', $types ) );

                
                self::$data[ 'custom-posts' ] = \apply_filters( 'Wpie/ImpExpTypes/Posts', $types );

                return self::$data[ 'custom-posts' ];
        }

        
        public static function getStandardTypes() {

                $types = [
                        'post'     => __( 'Post', 'wp-import-export' ),
                        'page'     => __( 'Page', 'wp-import-export' ),
                        'users'    => __( 'Users', 'wp-import-export' ),
                        'comments' => __( 'Comments', 'wp-import-export' )
                ];

                
                return \apply_filters( 'Wpie/ImpExpTypes/Standard', $types );
        }

        
        private static function getPostTypes() {

                return \get_post_types( [ '_builtin' => false, 'show_ui' => true ] );
        }

        
        private static function getExcludeTypes() {

                $types = [
                        'attachment',
                        'revision',
                        'nav_menu_item',
                        'shop_webhook',
                        'import_users',
                        'wp-types-group',
                        'wp-types-user-group',
                        'wp-types-term-group',
                        'custom_css',
                        'customize_changeset',
                        'oembed_cache',
                        'wp_block',
                        'user_request',
                        'scheduled-action',
                        'wp_global_styles',
                        'wp_template',
                        'wp_template_part',
                        'wp_navigation'
                ];

                
                return apply_filters( 'Wpie/ImpExpTypes/Posts/Excludes', $types );
        }

        
        public static function getSupportedTaxonomies() {

                if ( isset( self::$data[ 'taxonomies' ] ) ) {
                        return self::$data[ 'taxonomies' ];
                }

                $taxonomies = \get_taxonomies( false, 'objects' );

                if ( Helper::isEmpty( $taxonomies ) ) {
                        return [];
                }

                $excludes = self::getExcludeTaxonomies();

                $taxonomyTypes = [];

                foreach ( $taxonomies as $key => $taxonomy ) {

                        if ( (is_array( $excludes ) && in_array( $key, $excludes )) || (isset( $taxonomy->show_in_nav_menus ) && $taxonomy->show_in_nav_menus === false) ) {
                                continue;
                        }

                        $taxonomyTypes[ $key ] = isset( $taxonomy->label ) ? $taxonomy->label : (ucwords( str_replace( '_', ' ', $key ) ));
                }

                asort( $taxonomyTypes, SORT_FLAG_CASE | SORT_STRING );

                unset( $taxonomies, $excludes );

                
                self::$data[ 'taxonomies' ] = \apply_filters( 'Wpie/ImpExpTypes/Taxonomy', $taxonomyTypes );

                return self::$data[ 'taxonomies' ];
        }

        
        private static function getExcludeTaxonomies() {

                $types = [ 'nav_menu', 'link_category', 'post_format' ];

                
                return apply_filters( 'Wpie/ImpExpTypes/Taxonomy/Excludes', $types );
        }

        
        public static function getContentTypeLabel( $contentType = "" ) {

                $contentTypes = Helper::getImpExptypes();

                return isset( $contentTypes[ $contentType ] ) ? $contentTypes[ $contentType ] : $contentTypes[ 'standard/post' ];
        }

}
