<?php




namespace WpieApp\Core\Helpers;

defined( 'WPIE__FILE__' ) || exit;


trait Module {

        
        private static $activeModule = null;

        
        public static function setActiveModule() {

                if ( self::$activeModule ) {
                        return true;
                }

                if ( Helper::isAjax() ) {

                        $module = Helper::sanitizeiKey( Helper::_post( 'module' ) );
                } else {
                        $module = Helper::sanitizeiKey( Helper::_get( 'page' ) );
                }

                $module = self::getValidModule( $module );

                if ( Helper::isEmptyStr( $module ) ) {
                        self::$activeModule = null;
                        return false;
                }

                self::$activeModule = $module;

                return true;
        }

        
        public static function getActiveModule() {

                if ( Helper::isEmptyStr( self::$activeModule ) ) {
                        self::setActiveModule();
                }

                return self::$activeModule;
        }

        
        public static function isActiveModule( $module = "" ) {

                $module = self::getValidModule( $module );

                return Helper::isNonEmptyStr( $module ) && $module == self::getActiveModule() ? true : false;
        }

        
        public static function validateModuleRequest( $moduleNamespace = "" ) {

                if ( Helper::isEmptyStr( $moduleNamespace ) ) {
                        exit();
                }

                if ( Helper::isEmptyStr( self::getModuleFromClass( $moduleNamespace ) ) ) {
                        exit();
                }
        }

        
        public static function activeModuleURL() {

                return WPIE_MODULES_URL . '/' . self::getActiveModule();
        }

        
        public static function selfModule( $moduleNamespace = "" ) {

                return self::getModuleFromClass( $moduleNamespace );
        }

        
        public static function getModuleFromClass( $class ) {

                $module = null;
                preg_match( '/WpieApp\\\Modules\\\(.+)\\\/iU', $class, $module );

                return is_array( $module ) && isset( $module[ 1 ] ) ? self::getValidModule( $module[ 1 ] ) : "";
        }

        
        private static function getValidModule( $module = "" ) {

                if ( Helper::isEmptyStr( $module ) ) {
                        return '';
                }

                $module = \preg_replace( [ '/^wpie[_\-]/', '/[^a-zA-Z0-9\-\_]/' ], '', strtolower( $module ) );
                $module = ucfirst( $module );

                // chech if exists entered module
                if ( !Helper::directoryExists( Helper::pathJoin( WPIE_MODULES_DIR, $module ) ) ) {
                        return '';
                }

                return $module;
        }

}
