<?php


namespace WpieApp\Core\Office\Converter;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Admin\AutoLoader;
use PhpOffice\PhpSpreadsheet\IOFactory;
use PhpOffice\PhpSpreadsheet\Writer\Csv;
use PhpOffice\PhpSpreadsheet\Writer\Xls;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Writer\Ods;

defined( 'ABSPATH' ) || exit;

class Excel {

        
        public static function convert( $file = "", $format = "" ) {

                if ( !is_readable( $file ) ) {
                        return new \WP_Error( 'php_format_convert_error', __( 'File is not readable', 'wp-import-export' ) );
                }

                $format = Helper::isEmptyStr( $format ) ? "" : Helper::sanitizeKey( $format );

                if ( Helper::isEmptyStr( $format ) || !in_array( $format, [ "xls", "xlsx", "ods", "csv" ] ) ) {
                        return new \WP_Error( 'php_format_convert_error', __( 'Invalid Spreadsheet Format', 'wp-import-export' ) );
                }
                
                AutoLoader::loadSpreadsheet();

                $spreadsheet = IOFactory::load( $file );

                switch ( $format ) {
                        case "xls":
                                $writer = new Xls( $spreadsheet );
                                break;
                        case "xlsx":
                                $writer = new Xlsx( $spreadsheet );
                                break;
                        case "ods":
                                $writer = new Ods( $spreadsheet );
                                break;
                        default:
                                $writer = new Csv( $spreadsheet );
                                break;
                }

                $dir = \pathinfo( $file, PATHINFO_DIRNAME );

                $filename = Helper::sanitizeFilename( \pathinfo( $file, PATHINFO_FILENAME ), $format );

                $writer->save( Helper::pathJoin( $dir, $filename ) );

                $spreadsheet->disconnectWorksheets();

                unset( $writer, $spreadsheet, $dir, $filename );

                return true;
        }

}
