<?php



namespace WpieApp\Core\Upgrade;

use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Upgrade {

        
        public static function init() {

                Core::init();
                
                Legacy::upgrade();
                
                self::load();

                self::update();
        }

        
        protected static function load() {

                $path = realpath( __DIR__ . DIRECTORY_SEPARATOR . 'Updates' );

                $fileList = Helper::getFilesystem()->dirlist( $path );

                if ( !Helper::isNonEmptyArray( $fileList ) ) {
                        return;
                }

                $installedVersion = Helper::getOption( 'version' );

                $prefix = 'Update_';

                foreach ( array_keys( $fileList ) as $file ) {

                        $name = \basename( $file );

                        if ( strpos( $name, $prefix ) !== 0 ) {
                                continue;
                        }

                        $className = __NAMESPACE__ . \substr( $name, 0, -4 );

                        if ( !class_exists( $className ) ) {
                                continue;
                        }

                        if ( !property_exists( $className, 'VERSION' ) || version_compare( $installedVersion, $className::VERSION, '>' ) ) {
                                continue;
                        }

                        new $className();
                }
        }

        
        private static function update() {

                if ( WPIE_VERSION === Helper::getOption( 'version' ) ) {
                        return;
                }

                Helper::setOption( 'version', WPIE_VERSION );
        }
}
