<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Filters;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Filter;
use WpieApp\Modules\Export\Controller\Items\Base\Filters\Filter as BaseFilter;
use WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Query\Order;
use WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Filters\Tables\StatsTable;

defined( 'WPIE__FILE__' ) || exit;


class Item extends BaseFilter {

        
        protected static $isJoinQueryAdded = false;

        
        protected static $tableAlias = "items";

        
        public static function addRule() {

                $element = Filter::getOption( "element", "field" );

                if ( !Helper::isNonEmptyStr( $element ) ) {
                        return false;
                }

                if ( in_array( $element, [ 'product_id', 'variation_id' ] ) ) {
                        return ItemMeta::addRule();
                }
                if ( in_array( $element, [ 'total_items' ] ) ) {
                        return StatsTable::addRule();
                }
                if ( !in_array( $element, [ 'product_title' ] ) ) {
                        return '';
                }

                static::addJoinQuery();

                $condition = Filter::getOption( 'condition' );

                if ( in_array( $condition, [ "not_equals", "not_contains", "not_in" ] ) ) {
                        static::addNotRule();
                        return;
                }

                static::add();
        }

        
        public static function add() {

                $condition = Filter::getOption( 'condition' );

                $data = Filter::getOption( 'value' );

                $field = static::getTableAlias() . ".`order_item_name`";

                $comparison = Filter::getOption( 'comparison' );

                $rule = Filter::bulidRule( $field, $data, $condition, $comparison );

                Filter::addWhere( static::getTableAlias() . ".`order_item_type` = 'line_item' AND " . $rule );
        }

        
        private static function addNotRule() {

                $condition = substr( Filter::getOption( "condition" ), 4 );

                $data = Filter::getOption( 'value' );

                $itemsAlias = Helper::randStr( "wpie_" ) . 'items';

                $field = $itemsAlias . ".`order_item_name`";

                $comparison = Filter::getOption( 'comparison' );

                $rule = Filter::bulidRule( $field, $data, $condition, $comparison );

                $subQuery = "SELECT " . $itemsAlias . ".`order_id` FROM " . DB::table( 'woocommerce_order_items' ) . " AS " . $itemsAlias .
                        " WHERE  " . $itemsAlias . ".`order_item_type` = 'line_item'  AND " . $rule;

                Filter::addWhere( static::getOrderTableAlias() . ".`id` NOT IN(" . $subQuery . ") AND " . static::getOrderTableAlias() . ".`" . static::getTableAliasField() . "` NOT IN(" . $subQuery . ")" );
        }

        
        public static function addJoinQuery() {

                if ( static::$isJoinQueryAdded ) {
                        return;
                }

                static::$isJoinQueryAdded = true;

                Filter::addJoin( "LEFT JOIN " . DB::table( 'woocommerce_order_items' ) . " AS " . static::getTableAlias() . "  ON (" . static::getOrderTableAlias() . ".`id` = " . static::getTableAlias() . ".`order_id`)" );
        }

        
        public static function getOrderTableAlias() {

                return Order::getTableAlias();
        }

        
        public static function getTableAliasField() {

                return 'parent_order_id';
        }
}
