<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller\Items\Product\Fields;

use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;
use WpieApp\Modules\Export\Controller\Items\Post\Fields\Taxonomy as PostTaxonomy;

defined( 'WPIE__FILE__' ) || exit;


class Product implements InterfaceField {

        
        public static function get() {

                $productFields = [
                        [
                                'label'   => esc_html__( "Type", 'wp-import-export' ),
                                'type'    => PostTaxonomy::FIELD_TYPE,
                                'element' => 'product_type'
                        ],
                        [
                                'label'      => esc_html__( "Visibility", 'wp-import-export' ),
                                'type'       => PostTaxonomy::FIELD_TYPE,
                                'element'    => 'product_visibility',
                                "isFiltered" => false,
                        ],
                        [
                                'label'       => esc_html__( "Featured", 'wp-import-export' ),
                                'type'        => PostTaxonomy::FIELD_TYPE,
                                'element'     => 'product_visibility',
                                'is_featured' => true,
                                "isFiltered"  => false,
                        ],
                        [
                                'label'   => esc_html__( "Shipping classes", 'wp-import-export' ),
                                'type'    => PostTaxonomy::FIELD_TYPE,
                                'element' => 'product_shipping_class'
                        ],
                        [
                                'label'   => esc_html__( "Enable reviews", 'wp-import-export' ),
                                'type'    => Standard::FIELD_TYPE,
                                'element' => 'comment_status'
                        ],
                        [
                                'label'   => esc_html__( "Grouped products", 'wp-import-export' ),
                                'type'    => Meta::FIELD_TYPE,
                                'element' => '_children'
                        ],
                        [
                                'label'   => esc_html__( "GTIN, UPC, EAN, or ISBN", 'wp-import-export' ),
                                'type'    => Meta::FIELD_TYPE,
                                'element' => '_global_unique_id'
                        ]
                ];

                $fields = [
                        "title"       => esc_html__( "Product", 'wp-import-export' ),
                        "priority"    => 24,
                        "dateCompare" => true,
                        "data"        => array_merge( $productFields, self::getFields() )
                ];

                
                return \apply_filters( 'Wpie/Export/Product/Fields/Product', $fields );
        }

        
        private static function getFields() {

                $excludes = [ '_product_attributes', '_product_version', '_product_image_gallery', '_product_attributes', '_children', '_default_attributes','_global_unique_id' ];

                $keys = array_diff( Meta::getProductMetas(), $excludes );

                
                $keys = \apply_filters( 'Wpie/Export/Product/Fields/Product/Pre', $keys );

                $nonFilterable = [ '_upsell_ids', '_crosssell_ids', 'downloadable_file_name', '_downloadable_files', '_download_limit', '_download_expiry', '_download_type', '_default_attributes' ];

                return Helper::getNormalizedField( $keys, Meta::FIELD_TYPE, true, $nonFilterable );
        }

}
