<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\Engines\Items;

use WC_Shipping_Rate;
use WC_Order_Item_Shipping;
use WpieApp\Modules\Import\Helpers\Helper;
use Automattic\WooCommerce\Utilities\NumberUtil;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Shipping extends Base {

        
        protected static $methods;

        
        public static function processItem() {

                self::setShippingMethod();
        }

        
        protected static function update() {

                $item = new WC_Order_Item_Shipping( self::$item );

                if ( is_null( self::$item ) ) {
                        $item->set_order_id( DataCenter::getId() );
                }

                if ( isset( self::$data[ 'name' ] ) ) {
                        $item->set_name( self::$data[ 'name' ] );
                }

                if ( isset( self::$data[ 'method_id' ] ) ) {
                        $item->set_method_id( self::$data[ 'method_id' ] );
                        $item->set_instance_id( self::$data[ 'instance_id' ] );
                }

                if ( isset( self::$data[ 'cost' ] ) ) {
                        $item->set_total( self::$data[ 'cost' ] );
                }

                if ( isset( self::$data[ 'taxes' ] ) ) {
                        $item->set_taxes( self::$data[ 'taxes' ] );
                }

                $id = $item->save();

                unset( $item );

                self::setMeta( self::$data[ 'meta' ], $id );

                return $id;
        }

        
        protected static function setMeta( $metas = [], $id = 0 ) {

                if ( !Helper::isNonEmptyArray( $metas ) ) {
                        return;
                }

                foreach ( $metas as $meta ) {

                        $key = isset( $meta[ 'key' ] ) ? $meta[ 'key' ] : '';

                        if ( !Helper::isNonEmptyStr( $key ) ) {
                                return;
                        }

                        $value = isset( $meta[ 'value' ] ) ? $meta[ 'value' ] : '';

                        \wc_update_order_item_meta( $id, $key, $value );
                }
        }

        
        protected static function setItem() {

                if ( DataCenter::isNewItem() ) {
                        return;
                }

                $items = DataCenter::getItem()->get_shipping_methods();

                $name = isset( self::$data[ 'name' ] ) ? self::$data[ 'name' ] : '';

                if ( !Helper::isNonEmptyArray( $items ) || !Helper::isNonEmptyStr( $name ) ) {
                        return;
                }

                foreach ( $items as $item ) {

                        if ( $name === $item->get_name() ) {
                                self::$item = $item;
                                break;
                        }
                }

                unset( $items, $name );
        }

        
        public static function setShippingMethod() {

                if ( is_null( self::$methods ) ) {
                        self::$methods = \WC()->shipping()->get_shipping_methods();
                }


                if ( !Helper::isNonEmptyArray( self::$methods ) ) {
                        return;
                }

                $method = isset( self::$data[ 'method' ] ) ? self::$data[ 'method' ] : '';

                if ( !Helper::isNonEmptyStr( $method ) ) {
                        return;
                }

                if ( isset( self::$methods[ $method ] ) ) {
                        self::$data[ 'method_id' ]   = $method;
                        self::$data[ 'instance_id' ] = self::$methods[ $method ]->get_instance_id();
                        return;
                }

                foreach ( self::$methods as $shipping ) {

                        $id = $shipping->get_rate_id();

                        $title = $shipping->get_title();

                        if ( $method === $id || $method === $title ) {

                                self::$data[ 'method_id' ]   = $method;
                                self::$data[ 'instance_id' ] = $shipping->get_instance_id();
                                break;
                        }
                }
        }
}
