<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\Engines\Items;

use WC_Tax;
use WC_Order_Item_Tax;
use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Order\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Tax extends Base {

        
        protected static $baseRates;

        
        public static function processItem() {

                self::setRateId();
        }

        protected static function update() {

                $item = new WC_Order_Item_Tax( self::$item );

                if ( is_null( self::$item ) ) {

                        $item->set_order_id( DataCenter::getId() );
                }
                if ( isset( self::$data[ 'rate' ] ) ) {
                        $item->set_rate( self::$data[ 'rate' ] );
                } else {

                        if ( isset( self::$data[ 'label' ] ) ) {
                                $item->set_label( self::$data[ 'label' ] );
                        }
                        if ( isset( self::$data[ 'code' ] ) ) {
                                $item->set_rate_code( self::$data[ 'code' ] );
                        }
                        if ( isset( self::$data[ 'percent' ] ) && method_exists( $item, 'set_rate_percent' ) ) {
                                $item->set_rate_percent( self::$data[ 'percent' ] );
                        }
                }

                if ( isset( self::$data[ 'total' ] ) ) {
                        $item->set_tax_total( self::$data[ 'total' ] );
                }

                $id = $item->save();

                unset( $item );

                return $id;
        }

        
        protected static function setItem() {

                if ( DataCenter::isNewItem() ) {
                        return;
                }

                $items = DataCenter::getItem()->get_taxes();

                if ( !Helper::isNonEmptyArray( $items ) ) {
                        return;
                }

                $rateCode = isset( self::$data[ 'code' ] ) ? self::$data[ 'code' ] : '';

                if ( !Helper::isNonEmptyStr( $rateCode ) ) {
                        return;
                }

                foreach ( $items as $item ) {

                        if ( $rateCode === $item->get_rate_code() ) {
                                self::$item = $item;
                                break;
                        }
                }

                unset( $items, $rateCode );
        }

        
        protected static function setRateId() {

                if ( !is_null( self::$item ) ) {
                        return;
                }

                $rateId = self::findRate();

                if ( 1 > $rateId ) {
                        return;
                }

                self::$data[ 'rate' ] = $rateId;
        }

        
        protected static function findRate() {

                $rateCode = isset( self::$data[ 'code' ] ) ? self::$data[ 'code' ] : '';

                $label = isset( self::$data[ 'label' ] ) ? self::$data[ 'label' ] : '';

                if ( !Helper::isNonEmptyStr( $rateCode ) && !Helper::isNonEmptyStr( $label ) ) {
                        return;
                }

                self::setRates();

                if ( is_null( self::$baseRates ) || !Helper::isNonEmptyArray( self::$baseRates ) ) {
                        return;
                }

                $rateId = 0;

                foreach ( self::$baseRates as $rate ) {

                        $baseRateCode = WC_Tax::get_rate_code( $rate );

                        if ( $rateCode === $baseRateCode ) {
                                $rateId = isset( $rate->tax_rate_id ) ? $rate->tax_rate_id : 0;
                                break;
                        }
                }
                if ( 0 < $rateId ) {
                        return $rateId;
                }

                foreach ( self::$baseRates as $rate ) {

                        $baseRateLabel = WC_Tax::get_rate_label( $rate );

                        if ( $label === $baseRateLabel ) {
                                $rateId = isset( $rate->tax_rate_id ) ? $rate->tax_rate_id : 0;
                                break;
                        }
                }

                return $rateId;
        }

        
        protected static function setRates() {

                if ( !is_null( self::$baseRates ) ) {
                        return;
                }

                self::$baseRates = DB::wpdb()->get_results( "SELECT `tax_rate_id`, `tax_rate_name`, `tax_rate_country`, `tax_rate_state`, `tax_rate_priority` FROM " . DB::table( 'woocommerce_tax_rates' ) );
        }
}
