<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Post\AutoDetect as Base;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\AutoDetect\Attributes;

defined( 'WPIE__FILE__' ) || exit;


class AutoDetect extends Base {

        
        protected static $attributes = [];

        
        protected static function setDefaults() {

                self::$attributes = [];

                parent::setDefaults();
        }

        
        protected static function processField( $field = '' ) {

                parent::processField( $field );

                static::updatePrice( $field );

                static::updateStock( $field );

                static::updateType( $field );

                static::updateVariations( $field );

                static::updateDataAndVisibility( $field );

                static::updateGeneral( $field );

                static::updateDownloadable( $field );

                static::updateShipping( $field );

                static::updateLinkedProducts( $field );

                static::updateAdvanced( $field );

                static::updateAttributes( $field );
        }

        
        protected static function updateStandard( $field = "" ) {

                parent::updateStandard( $field );

                $fields = [
                        'productname'             => 'title',
                        'productdescription'      => 'content',
                        'productshortdescription' => 'excerpt',
                        'enablereviews'           => 'comment_status',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'standard/' . $fields[ $field ], $field );
        }

        
        protected static function updatePrice( $field = "" ) {

                $fields = [
                        'regularprice'       => 'regular',
                        'saleprice'          => 'sale',
                        'salepricedatesfrom' => 'date-from',
                        'salepricedatesto'   => 'date-to',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                if ( in_array( $field, [ 'salepricedatesfrom', 'salepricedatesto' ] ) ) {
                        static::updateField( 'price/' . $fields[ $field ] . '/data', $field );
                        static::updateList( 'price/date' );
                        return;
                }

                static::update( 'price/' . $fields[ $field ], $field );
        }

        
        protected static function updateStock( $field = "" ) {

                $fields = [
                        'stock'            => 'quantity',
                        'stockstatus'      => 'status',
                        'managestock'      => 'manage',
                        'sku'              => 'sku',
                        'gtinupceanorisbn' => 'gtin',
                        'lowstockamount'   => 'low-stock-threshold',
                        'backorders'       => 'backorders',
                        'soldindividually' => 'sold-individually',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'stock/' . $fields[ $field ], $field );
        }

        
        protected static function updateType( $field = "" ) {

                $fields = [
                        'type' => 'product-type',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'type/' . $fields[ $field ], $field );
        }

        
        protected static function updateVariations( $field = "" ) {

                $fields = [
                        'id'                   => 'data',
                        'parentid'             => 'parent',
                        'variationdescription' => 'description',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                if ( in_array( $field, [ 'id', 'parentid' ] ) ) {
                        static::updateField( 'variation/method/option', 'parent-child', false );
                        static::updateField( 'variation/method/parent-child/' . $fields[ $field ], $field );
                        static::updateList( 'variation/method' );
                        return;
                }

                static::update( 'variation/' . $fields[ $field ], $field );
        }

        
        protected static function updateDataAndVisibility( $field = "" ) {

                $fields = [
                        'virtual'    => 'virtual',
                        'featured'   => 'featured',
                        'visibility' => 'visibility',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'data-and-visibility/' . $fields[ $field ], $field );
        }

        
        protected static function updateGeneral( $field = "" ) {

                $fields = [
                        'taxstatus'  => 'tax-status',
                        'taxclass'   => 'tax-class',
                        'producturl' => 'product-url',
                        'buttontext' => 'button-text',
                ];
                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'general/' . $fields[ $field ], $field );
        }

        
        protected static function updateDownloadable( $field = "" ) {

                $fields = [
                        'downloadable'         => 'downloadable',
                        'downloadablefilename' => 'name',
                        'downloadablefiles'    => 'urls',
                        'downloadlimit'        => 'limit',
                        'downloadexpiry'       => 'expiry',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                if ( in_array( $field, [ 'downloadablefilename', 'downloadablefiles' ] ) ) {
                        static::updateField( 'downloadable/files/' . $fields[ $field ], $field );
                        static::updateList( 'downloadable/files' );
                        return;
                }

                static::update( 'downloadable/' . $fields[ $field ], $field );
        }

        
        protected static function updateShipping( $field = "" ) {

                $fields = [
                        'weight'          => 'weight',
                        'length'          => 'length',
                        'width'           => 'width',
                        'height'          => 'height',
                        'shippingclasses' => 'shipping-class',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                if ( in_array( $field, [ 'length', 'width', 'height' ] ) ) {
                        static::updateField( 'shipping/' . $fields[ $field ] . '/data', $field );
                        static::updateList( 'shipping/dimensions' );
                        return;
                }


                static::update( 'shipping/' . $fields[ $field ], $field );
        }

        
        protected static function updateLinkedProducts( $field = "" ) {

                $fields = [
                        'upsellids'       => 'upsells',
                        'crosssellids'    => 'cross-sells',
                        'groupedproducts' => 'grouped',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'linked-products/' . $fields[ $field ], $field );
        }

        
        protected static function updateAdvanced( $field = "" ) {

                $fields = [
                        'purchasenote' => 'purchase-note',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'advanced/' . $fields[ $field ], $field );
        }

        
        protected static function updateAttributes( $field = "" ) {

                if ( Helper::strStartsWith( 'attribute', $field ) ) {
                        self::$attributes[] = $field;
                        return;
                }

                $fields = [
                        'defaultattributes' => 'default',
                ];

                if ( !isset( $fields[ $field ] ) ) {
                        return;
                }

                static::update( 'attributes/' . $fields[ $field ], $field );
        }

        
        protected static function setAttributes() {

                $fields = self::getSiteFieldData( 'attribute' );

                $attributes = Attributes::get( $fields, self::$attributes );

                if ( !Helper::isNonEmptyArray( $attributes ) ) {
                        return;
                }

                static::updateField( 'attribute', $attributes, false );

                static::updateList( 'attributes/attribute' );
        }

        
        protected static function processExtra() {

                self::setAttributes();

                parent::processExtra();
        }

        
        protected static function DiscoverAlternative() {
                AutoDetectAlternative::init();
        }
}
