<?php



namespace WpieApp\Extensions\Import\Wpml\Controller\Items\Post;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Post\Search\Post;
use WpieApp\Extensions\Import\Wpml\Controller\Items\Base\Filters as BaseFilters;

defined( 'WPIE__FILE__' ) || exit;


class Filters extends BaseFilters {

        
        protected static $isInit = false;

        
        protected static function remove() {

                global $sitepress, $iclTranslationManagement;

                \remove_action( 'save_post', [ $sitepress, 'save_post_actions' ], 10 );

                \remove_action( 'save_post', [ $sitepress->post_translations(), 'save_post_actions' ], 100 );

                if ( !is_null( $iclTranslationManagement ) ) {
                        \remove_action( 'save_post', [ $iclTranslationManagement, 'save_post_actions' ], 11 );
                }
        }

        
        protected static function add() {

                \add_filter( 'Wpie/Import/Item/Query/Join', [ __CLASS__, 'addJoin' ], 10, 2 );

                \add_filter( 'Wpie/Import/Item/Query/Where', [ __CLASS__, 'addWhere' ], 10, 2 );

                //update Term Language
                \add_action( 'create_term', [ __CLASS__, 'updateTerm' ], 1, 3 );
        }

        
        public static function addJoin( $join = '', $table = '' ) {

                if ( !Helper::isNonEmptyStr( static::getLanguage() ) ) {
                        return $join;
                }

                $join .= ' LEFT JOIN ' . DB::table( 'icl_translations' ) . '  AS ' . static::getTableAlias() . " ON (" . $table . '.`ID` = ' . static::getTableAlias() . ".`element_id` )";

                return $join;
        }

        
        public static function addWhere( $where = '', $table = '' ) {

                if ( !Helper::isNonEmptyStr( static::getLanguage() ) ) {
                        return $where;
                }

                $elementType = 'post_' . Settings::getContentType();

                $query = DB::wpdb()->prepare( "  " . static::getTableAlias() . ".`element_type` = %s AND " . static::getTableAlias() . ".`language_code` IN ('" . static::getLanguage() . "') ", $elementType );

                return ' (' . $where . ') AND (' . $query . ') ';
        }

        
        public static function getTranslation( $lang, $options ) {

                static::$language = $lang;

                $post = Post::Search( $options );

                static::$language = '';

                return $post;
        }

        
        public static function updateTerm( $termId, $termTaxonomyId, $taxonomy ) {

                if ( !Helper::isNonEmptyStr( static::getLanguage() ) ) {
                        return;
                }

                global $sitepress;

                $sitepress->set_element_language_details( $termTaxonomyId, 'tax_' . $taxonomy, false, static::getLanguage() );
        }
}
