<?php




namespace WpieApp\Modules\Base\Controller;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Base\Model\Settings as SettingModel;

defined( 'WPIE__FILE__' ) || exit;


class Settings1 {

	
	private static $data = [];

	
	private static $isLoaded = false;

	
	public static function load( $data = null ) {

		if ( self::$isLoaded ) {
			return false;
		}

		if ( !Helper::isNonEmptyArray( $data ) || !isset( $data[ 'type' ] ) ) {
			return false;
		}

		self::$data = self::sanitizeData( $data );

		if ( !Helper::isNonEmptyArray( self::$data ) ) {
			self::$data = [];
			return false;
		}

		self::$data[ 'options' ] = isset( $data[ 'options' ] ) && Helper::isNonEmptyArray( $data[ 'options' ] ) ? self::decodeOptions( $data[ 'options' ] ) : [];

		self::$data[ 'log' ] = isset( $data[ 'log' ] ) && Helper::isNonEmptyArray( $data[ 'log' ] ) ? $data[ 'log' ] : [];

		self::$isLoaded = true;

		return true;
	}

	
	private static function decodeOptions( $options = [] ) {

		if ( !Helper::isNonEmptyArray( $options ) ) {
			return $options;
		}

		if ( isset( $options[ 'filters' ] ) ) {
			$filters		 = Helper::jsonDecode( $options[ 'filters' ] );
			$options[ 'filters' ]	 = Helper::isEmpty( $filters ) ? [] : \wp_unslash( $filters );
		}

		if ( isset( $options[ 'fields' ] ) ) {
			$fields			 = Helper::jsonDecode( $options[ 'fields' ], true );
			$options[ 'fields' ]	 = Helper::isNonEmptyArray( $fields ) ? \wp_unslash( $fields ) : [];
		}

		if ( isset( $options[ 'customFields' ] ) ) {
			$customFields			 = Helper::jsonDecode( $options[ 'customFields' ], true );
			$options[ 'customFields' ]	 = Helper::isNonEmptyArray( $customFields ) ? \wp_unslash( $customFields ) : [];
		}

		if ( isset( $options[ 'availableFields' ] ) ) {
			$availableFields		 = Helper::jsonDecode( $options[ 'availableFields' ], true );
			$options[ 'availableFields' ]	 = Helper::isNonEmptyArray( $availableFields ) ? \wp_unslash( $availableFields ) : [];
		}

		return $options;
	}

	
	protected static function sanitizeData( $data = null ) {

		if ( !Helper::isNonEmptyArray( $data ) ) {
			return false;
		}

		$newData = [];

		foreach ( $data as $key => $val ) {

			switch ( $key ) {
				case "status":
				case "type":
				case "sub_type":
				case "process":
				case "process_type":
					$newData[ $key ] = Helper::sanitizeKey( $val );
					break;
				case "uid":
				case "name":
				case "filename":
				case "filedir":
				case "user":
					$newData[ $key ] = Helper::sanitizeText( $val );
					break;
				case "id":
				case "total":
				case "parent":
				case "is_locked":
				case "records_per_iteration":
					$newData[ $key ] = \absint( $val );
					break;
			}
		}

		return $newData;
	}

	
	public static function loadByID( $id = null ) {

		if ( self::$isLoaded ) {
			return false;
		}
		$template = SettingModel::getSettingById( $id );

		if ( !Helper::isNonEmptyArray( $template ) ) {
			return false;
		}

		self::$data		 = self::sanitizeData( $template );
		self::$data[ 'options' ] = isset( $template[ 'options' ] ) && Helper::isNonEmptyStr( $template[ 'options' ] ) ? \maybe_unserialize( $template[ 'options' ] ) : [];
		self::$data[ 'log' ]	 = isset( $template[ 'log' ] ) && Helper::isNonEmptyStr( $template[ 'log' ] ) ? \maybe_unserialize( $template[ 'log' ] ) : [];

		self::$isLoaded = true;
		return true;
	}

	
	public static function get( $option = "", $default = "" ) {

		if ( Helper::isEmptyStr( $option ) ) {
			return $default;
		}

		$data = null;

		if ( isset( self::$data[ $option ] ) ) {
			$data = self::$data[ $option ];
		} elseif ( isset( self::$data[ 'options' ][ $option ] ) ) {
			$data = self::$data[ 'options' ][ $option ];
		}

		$data = Helper::isEmpty( $data ) ? $default : $data;

		
		return \apply_filters( 'Wpie/Settings', $data, $option );
	}

	
	public static function set( $option = "", $value = "", $isOption = true ) {

		if ( Helper::isEmptyStr( $option ) ) {
			return false;
		}

		if ( !$isOption && in_array( $option, [ 'status', 'log', 'is_locked', 'filename', 'total', 'records_per_iteration' ] ) ) {
			self::$data[ $option ] = $value;
		} else {
			self::$data[ 'options' ][ $option ] = $value;
		}

		return true;
	}

	
	public static function updateLog( $option = "" ) {

		if ( Helper::isEmptyStr( $option ) || $option === "processed" ) {
			return false;
		}

		if ( !isset( self::$data[ 'log' ] ) ) {
			self::$data[ 'log' ] = [];
		}
		if ( !isset( self::$data[ 'log' ][ $option ] ) ) {
			self::$data[ 'log' ][ $option ] = 0;
		}
		if ( !isset( self::$data[ 'log' ][ 'processed' ] ) ) {
			self::$data[ 'log' ][ 'processed' ] = 0;
		}

		self::$data[ 'log' ][ $option ]++;

		self::$data[ 'log' ][ 'processed' ]++;

		$fields = [ 'log' ];

		if ( self::$data[ 'log' ][ 'processed' ] >= self::$data[ 'total' ] ) {

			self::$data[ 'status' ] = 'completed';

			$fields[] = 'status';
		}

		self::save( $fields );

		return true;
	}

	
	public static function getLog( $option = "" ) {

		if ( Helper::isEmptyStr( $option ) ) {
			return 0;
		}

		if ( isset( self::$data[ 'log' ] ) && isset( self::$data[ 'log' ][ $option ] ) ) {
			return self::$data[ 'log' ][ $option ];
		}

		return 0;
	}

	
	public static function getList() {

		return SettingModel::getList();
	}

	
	public static function recordsPerIteration() {

		return RecordsPerIteration::get();
	}

	
	public static function save( $fields = false ) {

		$id = SettingModel::save( $fields );

		if ( \absint( self::get( "id" ) ) < 1 ) {
			self::$data[ "id" ] = $id;
		}

		return $id;
	}

	
	public static function delete( $ids = [] ) {

		SettingModel::delete( $ids );
	}

}
