<?php



namespace WpieApp\Modules\Base\Model;

use WP_Error;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;

defined( 'WPIE__FILE__' ) || exit;

class Settings {

        
        protected static $data = [];

        
        public static function getAll( $process = "import" ) {

                $template = DB::wpdb()->get_results( DB::wpdb()->prepare( "SELECT `id`,`content_type`,`category`,`process_type`,`name`,`file`,`created_date` FROM " . DB::getPluginTable() . " where `process` = %s and `status` NOT IN ( 'draft', 'init','failed') ", $process ), ARRAY_A );

                if ( is_array( $template ) ) {
                        return $template;
                }

                return [];
        }

        
        public static function getList() {

                $content_type = Helper::isNonEmptyStr( static::get( "content_type" ) ) ? static::get( "content_type" ) : "post";

                $process = Helper::isNonEmptyStr( static::get( "process" ) ) ? static::get( "process" ) : "import";

                $process_type = Helper::isNonEmptyStr( static::get( "process_type" ) ) ? static::get( "process_type" ) : "regular";

                $taxQuery = "";

                if ( Helper::isNonEmptyStr( static::get( "category" ) ) ) {

                        $taxQuery = DB::wpdb()->prepare( " AND `category` = %s ", static::get( "category" ) );
                }

                $template = DB::wpdb()->get_results( DB::wpdb()->prepare( "SELECT `id`,`name`,`created_date` FROM " . DB::getPluginTable() . " where `content_type` = %s AND `process_type` = %s AND `process` = %s $taxQuery", $content_type, $process_type, $process ), ARRAY_A );

                if ( is_array( $template ) ) {
                        return $template;
                }

                return false;
        }

        
        public static function getSettingById( $id = null ) {

                if ( intval( $id ) === 0 ) {
                        return false;
                }

                $template = DB::wpdb()->get_row( DB::wpdb()->prepare( "SELECT * FROM " . DB::getPluginTable() . " where `id` = %d", $id ), ARRAY_A );

                if ( is_array( $template ) ) {
                        return $template;
                }

                return false;
        }

        
        public static function save( $fields = false ) {

                if ( \absint( static::get( "id" ) ) > 0 ) {
                        return self::update( static::get( "id" ), $fields );
                } else {
                        if ( self::isExist( static::get( "name" ) ) ) {
                                return new \WP_Error( 'save_settings', __( 'Settings name already exist', 'wp-import-export' ) );
                        }
                        return self::insert();
                }
        }

        
        private static function isExist( $name = "" ) {

                $name = Helper::isNonEmptyStr( $name ) ? Helper::sanitizeText( $name ) : '';

                if ( !Helper::isNonEmptyStr( $name ) ) {
                        return false;
                }

                $id = DB::wpdb()->get_var( DB::wpdb()->prepare( "SELECT `id` FROM " . DB::getPluginTable() . " where `name` = %s Limit 0,1", $name ) );

                if ( intval( $id ) > 0 ) {
                        return true;
                }

                return false;
        }

        
        private static function update( $id = 0, $fields = false ) {


                if ( Helper::toInt( $id ) < 1 ) {
                        return;
                }

                if ( $fields !== false && !is_array( $fields ) ) {
                        $fields = [ $fields ];
                }

                $template = [ "updated_date" => Date::now() ];

                if ( $fields === false || (is_array( $fields ) && in_array( "options", $fields ) ) ) {
                        $template[ "options" ] = Helper::isNonEmptyArray( static::get( "options" ) ) ? \maybe_serialize( static::get( "options" ) ) : "";
                }
                if ( $fields === false || (is_array( $fields ) && in_array( "status", $fields ) ) ) {
                        $template[ "status" ] = Helper::sanitizeKey( static::get( "status" ) );
                }
                if ( $fields === false || ( is_array( $fields ) && in_array( "is_locked", $fields ) ) ) {
                        $template[ "is_locked" ] = intval( static::get( "is_locked" ) );
                }
                if ( $fields === false || ( is_array( $fields ) && in_array( "total", $fields ) ) ) {
                        $template[ "total" ] = intval( static::get( "total" ) );
                }
                if ( $fields === false || ( is_array( $fields ) && in_array( "content_type", $fields ) ) ) {
                        $template[ "content_type" ] = Helper::sanitizeKey( static::get( "content_type" ) );
                }
                if ( $fields === false || ( is_array( $fields ) && in_array( "category", $fields ) ) ) {
                        $template[ "category" ] = Helper::sanitizeKey( static::get( "category" ) );
                }
                if ( $fields === false || ( is_array( $fields ) && in_array( "name", $fields ) ) ) {
                        $template[ "name" ] = Helper::isNonEmptyStr( static::get( "name" ) ) ? Helper::sanitizeFilename( static::get( "name" ) ) : "";
                }
                if ( $fields === false || ( is_array( $fields ) && in_array( "process_type", $fields ) ) ) {
                        $template[ "process_type" ] = Helper::sanitizeKey( static::get( "process_type" ) );
                }
                if ( $fields === false || ( is_array( $fields ) && in_array( "file", $fields ) ) ) {
                        $template[ "file" ] = Helper::isNonEmptyStr( static::get( "file" ) ) ? Helper::sanitizeFilename( static::get( "file" ) ) : "";
                }
                if ( $fields === false || ( is_array( $fields ) && in_array( "records_per_iteration", $fields ) ) ) {
                        $template[ "records_per_iteration" ] = intval( static::get( "records_per_iteration" ) );
                }

                if ( $fields === false || (is_array( $fields ) && in_array( "log", $fields ) ) ) {

                        $template[ "log" ] = Helper::isNonEmptyArray( static::get( "log" ) ) ? \maybe_serialize( map_deep( static::get( "log" ), 'absint' ) ) : "";
                }

                DB::wpdb()->update( DB::getPluginTable(), $template, [ 'id' => $id ] );

                unset( $template );

                return $id;
        }

        
        public static function duplicate( $options = [] ) {

                $options = Helper::isNonEmptyArray( $options ) ? $options : [];

                $current_time = Date::now();

                $defaults = [
                        "uid"          => Helper::randStr(),
                        "status"       => "draft",
                        "process_type" => "regular",
                        "log"          => "",
                        "filedir"      => Helper::randStr(),
                        "parent"       => absint( static::get( "id", 0 ) ),
                        "is_locked"    => 0,
                        "created_date" => $current_time,
                        "updated_date" => $current_time,
                ];

                $options = Helper::isNonEmptyArray( $options ) ? array_replace( $defaults, $options ) : $defaults;

                return self::insert( $options );
        }

        
        public static function saveTemplate( $id = 0 ) {

                if ( Helper::toInt( $id ) > 1 ) {

                        return self::update( $id, [ 'options' ] );
                }

                if ( self::isExist( static::getOption( "options/setting/name" ) ) ) {
                        return new WP_Error( 'wpieError', __( "Setting Name Already Exist", 'wp-import-export' ) );
                }

                $current_time = Date::now();

                $options = [
                        "uid"          => Helper::randStr(),
                        "status"       => "completed",
                        "process_type" => "setting",
                        "log"          => "",
                        "filedir"      => Helper::randStr(),
                        "name"         => static::getOption( "options/setting/name" ),
                        "parent"       => 0,
                        "is_locked"    => 0,
                        "created_date" => static::get( "created_date", $current_time ),
                        "updated_date" => static::get( "updated_date", $current_time ),
                ];

                return self::insert( $options );
        }

        
        private static function insert( $options = [] ) {

                $current_time = Date::now();

                $defaults = [
                        "uid"                   => Helper::sanitizeKey( static::get( "uid", Helper::randStr() ) ),
                        "status"                => Helper::sanitizeKey( static::get( "status", "draft" ) ),
                        "content_type"          => Helper::sanitizeKey( static::get( "content_type" ) ),
                        "category"              => Helper::sanitizeKey( static::get( "category" ) ),
                        "process"               => Helper::sanitizeKey( static::get( "process", "import" ) ),
                        "process_type"          => Helper::sanitizeKey( static::get( "process_type", "regular" ) ),
                        "options"               => Helper::isNonEmptyArray( static::get( "options" ) ) ? \maybe_serialize( static::get( "options" ) ) : "",
                        "log"                   => Helper::isNonEmptyArray( static::get( "log" ) ) ? \maybe_serialize( static::get( "log" ) ) : "",
                        "total"                 => absint( static::get( "total" ) ),
                        "records_per_iteration" => absint( static::get( "records_per_iteration" ) ),
                        "name"                  => Helper::sanitizeText( static::get( "name" ) ),
                        "filedir"               => Helper::sanitizeKey( static::get( "filedir", Helper::randStr() ) ),
                        "file"                  => static::get( "file" ),
                        "user"                  => static::get( "user", Helper::getCurrentUserEmail() ),
                        "parent"                => absint( static::get( "parent" ) ),
                        "is_locked"             => absint( static::get( "is_locked" ) ),
                        "created_date"          => static::get( "created_date", $current_time ),
                        "updated_date"          => static::get( "updated_date", $current_time ),
                ];

                //insert template data
                DB::wpdb()->insert( DB::getPluginTable(), Helper::isNonEmptyArray( $options ) ? array_replace( $defaults, $options ) : $defaults );

                $id = DB::wpdb()->insert_id;

                //clear emory
                unset( $current_time, $defaults );
                return $id;
        }

        
        public static function delete( $ids = [] ) {

                if ( !is_array( $ids ) ) {
                        $ids = [ $ids ];
                }

                $ids = array_filter( array_map( 'absint', $ids ) );

                if ( !Helper::isNonEmptyArray( $ids ) ) {
                        return;
                }

                DB::wpdb()->query( "DELETE FROM " . DB::getPluginTable() . " WHERE id IN (" . Helper::arrTostr( $ids ) . ")" );
        }

        
        public static function get( $option = "", $default = "" ) {
                return '';
        }

        
        public static function getOption( $option = "", $default = "" ) {
                return '';
        }
}
