<?php



namespace WpieApp\Modules\Debug\View\Logs\SystemInfo;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Utils\DB;

defined( 'WPIE__FILE__' ) || exit;


class Server {

        
        public static function get() {

                return [
                        "label" => __( 'Server', 'wp-import-export' ),
                        "order" => 30,
                        "data"  => [
                                'server_info'               => [
                                        'label' => __( 'Server info', 'wp-import-export' ),
                                        'data'  => Helper::_server( 'SERVER_SOFTWARE' ),
                                ],
                                'php_version'               => [
                                        'label' => __( 'PHP version', 'wp-import-export' ),
                                        'data'  => phpversion(),
                                ],
                                'php_post_max_size'         => [
                                        'label' => __( 'PHP post max size', 'wp-import-export' ),
                                        'data'  => ini_get( 'post_max_size' ),
                                ],
                                'php_max_execution_time'    => [
                                        'label' => __( 'PHP max execution time', 'wp-import-export' ),
                                        'data'  => ( int ) ini_get( 'max_execution_time' ),
                                ],
                                'php_max_input_vars'        => [
                                        'label' => __( 'PHP max input vars', 'wp-import-export' ),
                                        'data'  => ( int ) ini_get( 'max_input_vars' ),
                                ],
                                'curl_version'              => [
                                        'label' => __( 'cURL version', 'wp-import-export' ),
                                        'data'  => self::getcUrlVersion(),
                                ],
                                'max_upload_size'           => [
                                        'label' => __( 'Max upload size', 'wp-import-export' ),
                                        'data'  => Helper::convertBytes2Hr( wp_max_upload_size() ),
                                ],
                                'mysql_version'             => [
                                        'label' => __( 'MySQL version', 'wp-import-export' ),
                                        'data'  => DB::wpdb()->db_version(),
                                ],
                                'default_timezone'          => [
                                        'label' => __( 'Default timezone', 'wp-import-export' ),
                                        'data'  => \date_default_timezone_get(),
                                ],
                                'fsockopen_or_curl_enabled' => [
                                        'label' => __( 'Is fsockopen/cURL enabled?', 'wp-import-export' ),
                                        'data'  => ( function_exists( 'fsockopen' ) || function_exists( 'curl_init' ) ),
                                ],
                                'domdocument_enabled'       => [
                                        'label' => __( 'Is DomDocument class enabled?', 'wp-import-export' ),
                                        'data'  => class_exists( 'DOMDocument' ),
                                ],
                                'gzip_enabled'              => [
                                        'label' => __( 'Is GZip enabled?', 'wp-import-export' ),
                                        'data'  => is_callable( 'gzopen' ),
                                ],
                                'mbstring_enabled'          => [
                                        'label' => __( 'Is mbstring enabled?', 'wp-import-export' ),
                                        'data'  => extension_loaded( 'mbstring' ),
                                ]
                        ]
                ];
        }

        
        private static function getcUrlVersion() {

                // Figure out cURL version, if installed.

                if ( function_exists( '\curl_version' ) ) {
                        $curl_version = \curl_version();
                        return (isset( $curl_version[ 'version' ] ) ? $curl_version[ 'version' ] : "") . ', ' . ( isset( $curl_version[ 'ssl_version' ] ) ? $curl_version[ 'ssl_version' ] : "");
                }

                if ( extension_loaded( 'curl' ) ) {
                        return __( 'cURL installed but unable to retrieve version.', 'wp-import-export' );
                }

                return false;
        }
}
