<?php



namespace WpieApp\Modules\Export\Controller;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Base\Model\Settings as SettingModel;
use WpieApp\Modules\Schedules\Controller\Event;
use WpieApp\Modules\Export\Controller\Items\Manager as Items;
use WpieApp\Modules\Logs\Controller\ManageLog;

defined( 'WPIE__FILE__' ) || exit;


class Ajax {

        
        public static function save() {

                $id = Settings::autoLoad();

                Settings::setOptions( Helper::_post( "wpie-settings" ) );

                
                \do_action( 'Wpie/Export/Settings/Save', Settings::get( 'category' ), Settings::get( 'content_type' ) );

                $total = Items::get( 'total' );

                Settings::set( "total", $total );

                Helper::ajaxResponse( [ 'id' => $id, 'total' => $total ] );
        }

        
        public static function updateSettings() {

                self::saveAll();

                Helper::ajaxResponse( Settings::saveTemplate( Helper::_post( "newId" ) ) );
        }

        
        public static function deleteSettings() {

                Helper::ajaxResponse( ManageLog::removeLogs( [ Helper::_post( "id" ) ] ) );
        }

        
        public static function getFields() {

                Settings::autoLoad();

                Helper::ajaxResponse( Items::get( 'fields' ) );
        }

        
        public static function getPreview() {

                Settings::autoLoad();

                Helper::ajaxResponse( Items::get( 'preview' ) );
        }

        
        public static function saveExport() {

                Settings::autoLoad();

                Settings::setOption( 'preExport', 'completed' );

                Helper::ajaxResponse( Items::get() );
        }

        
        public static function exportData() {

                Settings::autoLoad();

                if ( 'completed' !== Settings::getOption( 'preExport' ) ) {
                        Utils::preExport();
                        Settings::setOption( 'preExport', 'completed' );
                }

                $result = Items::get();

                if ( 'processing' === Settings::get( 'status' ) ) {
                        Settings::set( [ 'status' => 'waiting' ] );
                }

                Helper::ajaxResponse( $result );
        }

        
        public static function preCompleteTasks() {

                Settings::autoLoad();

                Helper::ajaxResponse( Utils::preCompleteTasks() );
        }

        
        public static function download() {

                Settings::autoLoad();

                $isBundle = intval( Helper::_post( 'is-bundle' ) ) === 1;

                Helper::ajaxResponse( Utils::download( $isBundle ) );
        }

        
        public static function updateOptions() {

                self::saveAll();

                Helper::ajaxSuccess();
        }

        
        public static function saveAll() {

                Settings::autoLoad();

                Settings::setOptions( Helper::_post( "wpie-settings" ) );

                
                \do_action( 'Wpie/Export/Settings/Update', Settings::get( 'category' ), Settings::get( 'content_type' ) );

                Utils::saveFields();
        }

        
        public static function updateFilter() {

                Settings::autoLoad();

                Settings::setOption( "filters", Helper::jsonDecode( Helper::_post( "filters" ), true ) );

                $total = Items::get( 'total' );

                Settings::set( "total", $total );

                Helper::ajaxSuccess( $total );
        }

        
        public static function getSettings() {

                Settings::autoLoad();

                Helper::ajaxSuccess( Settings::getSettings() );
        }

        
        public static function getSetting() {

                Settings::autoLoad();

                $data = [
                        "process_type" => Settings::get( 'process_type' ),
                        "content_type" => Settings::get( 'content_type' ),
                        "category"     => Settings::get( 'category' ),
                        "options"      => Settings::get( 'options' ),
                        "total"        => Settings::get( 'total' ),
                        "file"         => Settings::get( 'file' ),
                ];

                Helper::ajaxResponse( $data );
        }

        
        public static function saveSchedule() {

                Settings::autoLoad();

                Settings::setOptions( Helper::_post( "wpie-settings" ) );

                $name = Settings::getOption( 'schedule/name' );

                if ( !Helper::isNonEmptyStr( $name ) ) {
                        Helper::ajaxError( __( 'Schedule name required', 'wp-import-export' ) );
                }

                $existingId = DB::wpdb()->get_var( DB::wpdb()->prepare( "SELECT id FROM " . DB::getPluginTable() . " where `name` = %s Limit 0,1", $name ) );

                if ( intval( $existingId ) > 0 ) {
                        Helper::ajaxError( __( 'Schedule name already exist', 'wp-import-export' ) );
                }

                Settings::set( [ 'process_type' => 'schedule', 'name' => $name, 'status' => 'completed' ] );

                Settings::setOption( 'info/contentTypeLabel', Helper::getContentTypeLabel( Settings::get( 'category' ) . '/' . Settings::get( 'content_type' ) ) );

                $id = Settings::get( 'id' );

                $interval = Settings::getOption( 'schedule/interval' );

                $start = Settings::getOption( 'schedule/start' );

                $isAdded = Event::add( $id, $interval, $start );

                Helper::ajaxResponse( is_wp_error( $isAdded ) ? $isAdded : __( 'Schedule Saved Successfully', 'wp-import-export' ) );
        }

        
        public static function setBgExport() {

                Settings::autoLoad();

                Settings::set( 'process_type', 'background' );

                Helper::ajaxSuccess( __( 'Settings Saved Successfully', 'wp-import-export' ) );
        }

        
        public static function updateStatus() {

                Settings::autoLoad();

                $status = Helper::sanitizeKey( Helper::_post( "status" ) );

                if ( in_array( Settings::get( 'status' ), [ 'completed', 'cancelled', 'failed', 'stopped' ] ) ) {
                        /* translators: %s: export Status */
                        Helper::ajaxError( sprintf( __( 'Export already %s', 'wp-import-export' ), Settings::get( 'status' ) ) );
                }

                $data = ('background' === $status) ? [ 'status' => 'processing', 'process_type' => 'background' ] : [ 'status' => $status ];

                Settings::set( $data );

                Helper::ajaxSuccess();
        }
}
