<?php



namespace WpieApp\Modules\Export\Controller\Items\Base\Filters;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;

defined( 'WPIE__FILE__' ) || exit;


class Rule {

        
        private static $query;

        
        private static $data;

        
        private static $condition;

        
        private static $field;

        
        public static function get( $field = "", $data = "", $condition = "", $comparison = "strings" ) {

                if ( !Helper::isNonEmptyStr( $field ) || !Helper::isNonEmptyStr( $condition ) ) {
                        return "";
                }

                self::$query     = "";
                self::$field     = $field;
                self::$data      = $data;
                self::$condition = $condition;

                self::compares( $comparison );

                return self::$query;
        }

        
        private static function compares( $comparison = "strings" ) {

                switch ( $comparison ) {
                        case "number":
                                self::compareNumbers();
                                break;
                        case "date":
                                self::compareDates();
                                break;
                        default:
                                self::comparestrings();
                                break;
                }
        }

        
        private static function comparestrings() {

                switch ( self::$condition ) {

                        case 'equals':
                                self::$query = self::$field . " " . DB::wpdb()->prepare( '= %s', self::$data );
                                break;
                        case 'not_equals':
                                self::$query = self::$field . " " . DB::wpdb()->prepare( '!= %s', self::$data );
                                break;
                        case 'contains':
                                self::$query = self::$field . " " . DB::wpdb()->prepare( 'LIKE %s', "%" . DB::wpdb()->esc_like( self::$data ) . "%" );
                                break;
                        case 'not_contains':
                                self::$query = self::$field . " " . DB::wpdb()->prepare( 'NOT LIKE %s', "%" . DB::wpdb()->esc_like( self::$data ) . "%" );
                                break;
                        case 'is_empty':
                                self::$query = self::$field . " IS NULL OR TRIM(" . self::$field . ") = ''";
                                break;
                        case 'is_not_empty':
                                self::$query = self::$field . " IS NOT NULL AND TRIM(" . self::$field . ") != ''";
                                break;
                        case 'in':
                        case 'not_in':

                                $inputData = [];

                                $newValue = Helper::strToArr( self::$data );

                                if ( Helper::isNonEmptyArray( $newValue ) ) {

                                        foreach ( $newValue as $val ) {
                                                $inputData[] = DB::wpdb()->prepare( '%s', $val );
                                        }
                                }
                                $inputData = Helper::isNonEmptyArray( $inputData ) ? implode( ",", $inputData ) : "";

                                $notIn = self::$condition === "not_in" ? "NOT" : "";

                                self::$query = Helper::isNonEmptyStr( $inputData ) ? self::$field . " " . $notIn . " IN (" . $inputData . ")" : false;

                                break;
                }

                self::$query = (self::$query === false ? false : " ( " . self::$query . " ) ");
        }

        
        private static function compareNumbers() {

                if ( preg_replace( '/\D/', "", self::$data ) === "" ) {
                        self::$query = false;
                        return false;
                }

                switch ( self::$condition ) {

                        case 'equals':
                                self::$query = self::$field . " " . DB::wpdb()->prepare( '= %d', Helper::toInt( self::$data ) );
                                break;
                        case 'not_equals':
                                self::$query = self::$field . " " . DB::wpdb()->prepare( '!= %d', Helper::toInt( self::$data ) );
                                break;
                        case 'greater':
                                self::$query = self::$field . " " . DB::wpdb()->prepare( '> %d', Helper::toInt( self::$data ) );
                                break;
                        case 'equals_or_greater':
                                self::$query = self::$field . " " . DB::wpdb()->prepare( '>= %d', Helper::toInt( self::$data ) );
                                break;
                        case 'less':
                                self::$query = self::$field . " " . DB::wpdb()->prepare( '< %d', Helper::toInt( self::$data ) );
                                break;
                        case 'equals_or_less':
                                self::$query = self::$field . " " . DB::wpdb()->prepare( '<= %d', Helper::toInt( self::$data ) );
                                break;
                        case 'is_empty':
                                self::$query = self::$field . " IS NULL OR TRIM(" . self::$field . ") = ''";
                                break;
                        case 'is_not_empty':
                                self::$query = self::$field . " IS NOT NULL OR TRIM(" . self::$field . ") != ''";
                                break;
                        case 'in':
                        case 'not_in':

                                $inputData = [];

                                $newValue = Helper::strToArr( self::$data );

                                if ( Helper::isNonEmptyArray( $newValue ) ) {

                                        foreach ( $newValue as $val ) {
                                                $inputData[] = DB::wpdb()->prepare( '%d', Helper::toInt( $val ) );
                                        }
                                }
                                $inputData = Helper::isNonEmptyArray( $inputData ) ? implode( ",", $inputData ) : "";

                                $notIn = self::$condition === "not_in" ? "NOT" : "";

                                self::$query = Helper::isNonEmptyStr( $inputData ) ? self::$field . " " . $notIn . " IN (" . $inputData . ")" : false;

                                break;
                }

                self::$query = (self::$query === false ? false : " ( " . self::$query . " ) ");
        }

        
        private static function compareDates() {

                switch ( self::$condition ) {

                        case 'equals':

                                if ( Helper::isNonEmptyStr( self::$data ) ) {

                                        self::buidDateQuery( "=" );
                                } else {
                                        self::$query = self::$field . " " . DB::wpdb()->prepare( '= %s', self::$data );
                                }

                                break;
                        case 'not_equals':
                                if ( Helper::isNonEmptyStr( self::$data ) ) {
                                        self::buidDateQuery( "!=" );
                                } else {
                                        self::$query = self::$field . " " . DB::wpdb()->prepare( ' != %s', self::$data );
                                }

                                break;
                        case 'greater':
                                if ( Helper::isNonEmptyStr( self::$data ) ) {
                                        self::buidDateQuery( ">" );
                                } else {
                                        self::$query = false;
                                }
                                break;
                        case 'equals_or_greater':
                                if ( Helper::isNonEmptyStr( self::$data ) ) {
                                        self::buidDateQuery( ">=" );
                                } else {
                                        self::$query = false;
                                }
                                break;
                        case 'less':
                                if ( Helper::isNonEmptyStr( self::$data ) ) {
                                        self::buidDateQuery( "<" );
                                } else {
                                        self::$query = false;
                                }
                                break;
                        case 'equals_or_less':
                                if ( Helper::isNonEmptyStr( self::$data ) ) {
                                        self::buidDateQuery( "<=" );
                                } else {
                                        self::$query = false;
                                }
                                break;
                        case 'is_empty':
                                self::$query = self::$field . " IS NULL OR TRIM(" . self::$field . ") = ''";
                                break;
                        case 'is_not_empty':
                                self::$query = self::$field . " IS NOT NULL OR TRIM(" . self::$field . ") != ''";
                                break;
                }

                self::$query = (self::$query === false ? false : " ( " . self::$query . " ) ");
        }

        
        private static function buidDateQuery( $condition = "" ) {

                $phpFormat = self::hasTimeData( self::$data ) ? "Y-m-d H:i:s" : "Y-m-d";

                $sqlFormat = self::hasTimeData( self::$data ) ? "%Y-%m-%d %H:%i:%s" : '%Y-%m-%d';

                $formats = [
                        [
                                "regexp" => '^[0-9]{4}-(0[1-9]|1[0-2])-([0-2][0-9]|3[0-1]) [0-9]{2}:[0-9]{2}:[0-9]{2}$',
                                "format" => '%Y-%m-%d %H:%i:%s',
                        ],
                        [
                                "regexp" => '^([0-2][0-9]|3[0-1])-(0[1-9]|1[0-2])-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}$',
                                "format" => '%d-%m-%y %H:%i:%s',
                        ],
                        [
                                "regexp" => '^[0-9]{4}-(0[1-9]|1[0-2])-([0-2][0-9]|3[0-1])$',
                                "format" => '%Y-%m-%d',
                        ],
                        [
                                "regexp" => '^([0-2][0-9]|3[0-1])-(0[1-9]|1[0-2])-[0-9]{4}$',
                                "format" => '%d-%m-%Y'
                        ],
                        [
                                "regexp" => '^(0[1-9]|1[0-2])/([0-2][0-9]|3[0-1])/[0-9]{4}$',
                                "format" => '%m/%d/%Y',
                        ],
                        [
                                "regexp" => '^([0-2][0-9]|3[0-1])/(0[1-9]|1[0-2])/[0-9]{4}$',
                                "format" => '%d/%m/%Y',
                        ],
                        [
                                "regexp" => '^[0-9]{4}/(0[1-9]|1[0-2])/([0-2][0-9]|3[0-1])$',
                                "format" => '%Y/%m/%d',
                        ],
                        [
                                "regexp" => '^(0[1-9]|1[0-2])/([0-2][0-9]|3[0-1])/[0-9]{2}$',
                                "format" => '%m/%d/%y',
                        ],
                        [
                                "regexp" => '^[A-Z][a-z]{2} ([0-2][0-9]|3[0-1]), [0-9]{4}$',
                                "format" => '%b %d, %Y',
                        ],
                        [
                                "regexp" => '^[A-Z][a-z]{2} ([0-2][0-9]|3[0-1]) [0-9]{4}$',
                                "format" => '%b %d %Y',
                        ],
                        [
                                "regexp" => '^([0-2][0-9]|3[0-1])/(0[1-9]|1[0-2])/[0-9]{2}$',
                                "format" => '%d/%m/%y',
                        ],
                        [
                                "regexp" => '^([0-2][0-9]|3[0-1])-(0[1-9]|1[0-2])-[0-9]{2}$',
                                "format" => '%d-%m-%y',
                        ],
                ];

                self::$query = " ( " . self::$field . " REGEXP '[0-9]' )";
                self::$query .= " AND (  ";

                foreach ( $formats as $formatData ) {

                        $regexp = isset( $formatData[ 'regexp' ] ) ? $formatData[ 'regexp' ] : "";
                        $format = isset( $formatData[ 'format' ] ) ? $formatData[ 'format' ] : "";

                        self::$query .= " (  " . DB::wpdb()->prepare( self::$field . " REGEXP %s AND STR_TO_DATE(" . self::$field . ", %s) IS NOT NULL AND DATE_FORMAT(STR_TO_DATE(" . self::$field . ", %s), %s)" . "  " . $condition . " DATE_FORMAT(%s,%s)", $regexp, $format, $format, $sqlFormat, Date::get( self::$data, $phpFormat ), $sqlFormat ) . " ) OR ";
                }

                self::$query .= " ( " .
                        self::$field . " REGEXP '^[0-9]{10,}$' AND UNIX_TIMESTAMP(" . self::$field . ") IS NOT NULL " .
                        " AND DATE_FORMAT(FROM_UNIXTIME(" . self::$field . "), '" . $sqlFormat . "'  " . $condition . " " . DB::wpdb()->prepare( '%s', Date::get( self::$data, $phpFormat ) ) . "))";

                self::$query .= ")";
        }

        
        private static function hasTimeData( $date = "" ) {

                if ( !Helper::isNonEmptyStr( $date ) ) {
                        return false;
                }

                $timestamp = strtotime( $date );

                $time = $timestamp !== false ? Date::getCoreDate( Date::TIMEFORMAT, $timestamp ) : "";

                return $time !== "" && $time != "00:00:00";
        }

}
