<?php



namespace WpieApp\Modules\Export\Controller\Items;

use WpieApp\Core\Office\Converter;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Core\Archive\Writer\Zip;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Post\Manager as Post;
use WpieApp\Modules\Export\Controller\Items\Taxonomy\Manager as Taxonomy;
use WpieApp\Modules\Export\Controller\Items\User\Manager as User;
use WpieApp\Modules\Export\Controller\Items\Comment\Manager as Comment;

defined( 'WPIE__FILE__' ) || exit;


class Manager {

        
        public static function get( $option = "data" ) {

                
                $category = \apply_filters( 'Wpie/Export/Init/Category', Settings::get( 'category' ) );

                if ( $category === "standard" ) {
                        return self::getStandardType( $option );
                } elseif ( $category === "posts" ) {
                        return self::getPosts( $option );
                } elseif ( $category === "comments" ) {
                        return self::getComments( $option );
                } elseif ( $category === "taxonomies" ) {
                        return self::getTaxonomies( $option );
                } elseif ( $category === "users" ) {
                        return self::getUsers( $option );
                } else {
                        return self::getCustomdata( $category, $option );
                }
        }

        
        private static function getStandardType( $option = "data" ) {

                $contentType = Settings::get( 'content_type' );

                if ( $contentType === "comments" ) {
                        return self::getComments( $option );
                } elseif ( $contentType === "users" ) {
                        return self::getUsers( $option );
                }

                return self::getPosts( $option );
        }

        
        private static function getComments( $option = "data" ) {

                $customProcessing = \apply_filters( 'Wpie/Export/Comments/Custom', false, Settings::get( 'content_type' ), $option );

                if ( $customProcessing !== false ) {
                        return $customProcessing;
                }

                return Comment::get( $option );
        }

        
        private static function getTaxonomies( $option = "data" ) {

                $customProcessing = \apply_filters( 'Wpie/Export/Taxonomies/Custom', false, Settings::get( 'content_type' ), $option );

                if ( $customProcessing !== false ) {
                        return $customProcessing;
                }

                return Taxonomy::get( $option );
        }

        
        private static function getUsers( $option = "data" ) {

                $customProcessing = \apply_filters( 'Wpie/Export/Users/Custom', false, Settings::get( 'content_type' ), $option );

                if ( $customProcessing !== false ) {
                        return $customProcessing;
                }

                return User::get( $option );
        }

        
        private static function getPosts( $option = "data" ) {

                $customProcessing = \apply_filters( 'Wpie/Export/Posts/Custom', false, Settings::get( 'content_type' ), $option );

                if ( $customProcessing !== false ) {
                        return $customProcessing;
                }

                return Post::get( $option );
        }

        
        private static function getCustomdata( $category, $option = "data" ) {

                return \apply_filters( 'Wpie/Export/Custom', '', $category, Settings::get( 'content_type' ), $option );
        }

}
