<?php



namespace WpieApp\Modules\Export\Controller;

use WpieApp\Core\Utils\Date;
use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Base\Controller\Settings as SettingBase;
use WpieApp\Modules\Export\Controller\Items\Base\RecordsPerIteration;

defined( 'WPIE__FILE__' ) || exit;


class Settings extends SettingBase {

        
        protected static $data = [];

        
        const EXPORT_FILE = "export.csv";

        
        public static function autoLoad() {

                $id = Helper::toInt( Helper::_post( "id" ) );

                if ( $id > 0 ) {
                        static::load( $id );
                        return $id;
                }

                $settings = Helper::_post( "settings" );

                if ( !static::autoLoadData( $settings ) ) {
                        return;
                }

                return static::save();
        }

        
        public static function autoLoadData( $settings = [] ) {

                if ( !Helper::isNonEmptyArray( $settings ) ) {

                        return false;
                }

                $default = [ 'process' => 'export' ];

                $data = Helper::isNonEmptyArray( $settings ) ? array_merge( $settings, $default ) : $default;

                static::load( $data );

                return true;
        }

        
        public static function getFilePath() {

                return static::getCurrentDir( "file" ) . DIRECTORY_SEPARATOR . static::get( "file" );
        }

        
        public static function getCurrentDir( $dir = "" ) {

                $filedir = parent::get( "filedir" );

                if ( !Helper::isNonEmptyStr( $filedir ) ) {
                        return false;
                }

                $importDir = Helper::pathJoin( WPIE_UPLOAD_EXPORT_DIR, $filedir );

                if ( !Helper::isNonEmptyStr( $dir ) ) {
                        return $importDir;
                }

                return Helper::pathJoin( $importDir, Helper::sanitizeKey( $dir ) );
        }

        
        public static function createImportDir( $dir = "" ) {

                if ( !Helper::isNonEmptyStr( $dir ) ) {
                        return false;
                }
                $path = static::getCurrentDir( $dir );

                if ( $path === false ) {
                        return false;
                }

                Helper::createDir( $path );

                return $path;
        }

        
        public static function getSettings() {

                $contentType = Settings::get( 'content_type' );

                $category = Settings::get( 'category' );

                $settings = DB::wpdb()->get_results( DB::wpdb()->prepare( "SELECT `id`,`content_type`,`category`,`process_type`,`name`,`file`,`created_date` FROM " . DB::getPluginTable() . " where `process` = 'export' AND `content_type` = %s AND `category` = %s AND `status` NOT IN ('draft','init') ORDER BY `id` DESC", $contentType, $category ), ARRAY_A );

                if ( Helper::isNonEmptyArray( $settings ) ) {

                        foreach ( $settings as $key => $data ) {
                                $data[ 'created_date' ] = isset( $data[ 'created_date' ] ) ? Date::getLocal( $data[ 'created_date' ] ) : '';
                                $settings[ $key ]       = $data;
                        }

                        return $settings;
                }

                return [];
        }

        
        public static function saveTempalte( $id = 0 ) {

                $contentType = Settings::get( 'content_type' );

                $category = Settings::get( 'category' );

                $template = DB::wpdb()->get_results( DB::wpdb()->prepare( "SELECT `id`,`content_type`,`category`,`process_type`,`name`,`file`,`created_date` FROM " . DB::getPluginTable() . " where `content_type` = %s AND `category` = %s AND `status` != 'draft' ORDER BY `id` DESC", $contentType, $category ), ARRAY_A );

                if ( is_array( $template ) ) {
                        return $template;
                }

                return [];
        }
        
        
        public static function recordsPerIteration() {

                return RecordsPerIteration::get(  );
        }
}
