<?php



namespace WpieApp\Modules\Export\View\ContentType;

use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Core\Utils\DB;

defined( 'WPIE__FILE__' ) || exit;


class ContentType {

        
        public static function getBlocks() {

                
                return \apply_filters(
                        'Wpie/Modules/Export/View/ContentType',
                        [
                                "title"     => __( 'Content Types', 'wp-import-export' ),
                                "isActive"  => true,
                                "menuClass" => "d-none",
                                "order"     => 5,
                                "desc"      => __( 'Export Content Types', 'wp-import-export' ),
                                "fields"    => \apply_filters( 'Wpie/Modules/Export/View/ContentType/Fields', self::getFields() )
                        ]
                );
        }

        
        public static function getFields() {

                if ( WPIE_WC_ONLY ) {
                        return [];
                }

                $rawTaxonomy = Helper::getSupportedTaxonomies();

                $taxonomies = Helper::processImpExptypes( "taxonomies", $rawTaxonomy );

                $fields      = [
                        "standard" => [
                                "order"       => 10,
                                "wrapper-col" => "col-lg-6",
                                "label"       => __( 'WordPress Standard', 'wp-import-export' ),
                                "sub-fields"  => [
                                        "post" => [
                                                "col-class"   => "cols",
                                                "type"        => "radio",
                                                "order"       => 5,
                                                "name"        => "content_type",
                                                "class"       => "wpie-content-type",
                                                "default"     => "",
                                                "description" => __( 'WordPress Defaults', 'wp-import-export' ),
                                                "choices"     => Helper::processImpExptypes( "standard", Helper::getStandardTypes() )
                                        ],
                                ],
                        ],
                        "taxonomy" => [
                                "order"       => 30,
                                "wrapper-col" => "col-lg-6",
                                "label"       => __( 'Taxonomies & Terms', 'wp-import-export' ),
                                "sub-fields"  => [
                                        "post" => [
                                                "col-class"   => "cols",
                                                "type"        => "radio",
                                                "order"       => 5,
                                                "name"        => "content_type",
                                                "class"       => "wpie-content-type",
                                                "default"     => "",
                                                "description" => __( 'Post Taxonomies & Terms', 'wp-import-export' ),
                                                "choices"     => $taxonomies,
                                                "hints"       => array_combine( array_keys( $taxonomies ), array_keys( $rawTaxonomy ) )
                                        ]
                                ],
                        ],
                ];
                $customPosts = Helper::getCustomPostTypes();

                if ( Helper::isNonEmptyArray( $customPosts ) ) {

                        $choices = Helper::processImpExptypes( "posts", $customPosts );

                        $fields[ 'custom-post' ] = [
                                "order"       => 20,
                                "wrapper-col" => "col-lg-6",
                                "label"       => __( 'Custom Posts', 'wp-import-export' ),
                                "sub-fields"  => [
                                        "post" => [
                                                "col-class"   => "cols",
                                                "type"        => "radio",
                                                "order"       => 5,
                                                "name"        => "content_type",
                                                "class"       => "wpie-content-type",
                                                "default"     => "",
                                                "description" => __( 'Custom Post Types', 'wp-import-export' ),
                                                "choices"     => $choices,
                                                "hints"       => array_combine( array_keys( $choices ), array_keys( $customPosts ) )
                                        ]
                                ]
                        ];
                }

                return $fields;
        }
}
