<?php




namespace WpieApp\Modules\Import\Controller;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\File\Record;
use WpieApp\Modules\Export\Controller\Settings as ExportSettings;
use WpieApp\Modules\Export\Controller\Items\Manager as ExportItems;

defined( 'WPIE__FILE__' ) || exit;


class AutoLoader {

        
        private static $fields = [];

        
        private static $labels = [];

        
        private static $data = [];

        
        public static function init() {

                self::$data = [];

                self::setExportSettings();

                Settings::autoLoad();

                self::setLabels();

                self::processFields();
 
                return self::$data;
        }

        
        private static function setLabels() {

                self::$labels = Record::get( "getLabels" );
        }

        
        private static function setExportSettings() {

                if ( Helper::isNonEmptyArray( self::$fields ) ) {
                        return;
                }

                $data = [
                        "category"     => Helper::_post( "category" ),
                        "content_type" => Helper::_post( "content_type" )
                ];

                ExportSettings::autoLoadData( $data );

                self::$fields = ExportItems::get( 'fields' );
        }

        
        private static function processFields() {


                if ( !Helper::isNonEmptyArray( self::$fields ) || !Helper::isNonEmptyArray( self::$labels ) ) {
                        return;
                }

                self::$data = [ 'fields' => [], "can-update" => [] ];

                foreach ( self::$fields as $fieldGroup ) {

                        if ( !Helper::isNonEmptyArray( $fieldGroup ) ) {
                                continue;
                        }

                        $fields = isset( $fieldGroup[ 'data' ] ) ? $fieldGroup[ 'data' ] : [];

                        if ( !Helper::isNonEmptyArray( $fields ) ) {
                                continue;
                        }

                        foreach ( $fields as $field ) {

                                $type = isset( $field[ 'type' ] ) ? $field[ 'type' ] : "";

                                $label = isset( $field[ 'label' ] ) ? $field[ 'label' ] : "";

                                if ( !Helper::isNonEmptyStr( $type ) || !Helper::isNonEmptyStr( $label ) ) {
                                        continue;
                                }

                                $key = Helper::sanitizeKey( $label );

                                if ( !in_array( $key, self::$labels ) ) {
                                        continue;
                                }

                                self::$data[ 'fields' ][ $type ][ $key ] = [ "data" => "{" . $key . "}" ];

                                self::$data[ 'can-update' ][ $type ][ $key ] = "1";
                        }
                }
        }

}
