<?php



namespace WpieApp\Modules\Import\Controller\File\Uploader\Local;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Core\Utils\FileUploadManager;

defined( 'WPIE__FILE__' ) || exit;


class Manager {

        
        public static function init() {

                $operation = Helper::_post( 'operation' );

                if ( $operation === "add-chunks" ) {
                        return self::addChunks();
                } elseif ( $operation === "merge-chunks" ) {
                        return self::mergeChunks();
                }
        }

        
        public static function addChunks() {

                $dir = Settings::createImportDir( 'temp' );

                if ( $dir === false ) {
                        return new \WP_Error( 'wpie_import_error', __( 'Failed to Crate Directory', 'wp-import-export' ) );
                }

                $chunk = Helper::toInt( Helper::_post( "chunk" ) ) + 1;

                $name = Helper::sanitizeFilename( Helper::_post( "name" ) );

                if ( $chunk === 1 ) {

                        if ( Helper::emptyDir( $dir ) === false ) {
                                return new \WP_Error( 'wpie_import_error', __( 'Failed to Empty Directory', 'wp-import-export' ) );
                        }

                        if ( !Helper::isSupportedFile( $name ) ) {
                                /* translators: %s: File Extensions */
                                return new \WP_Error( 'wpie_import_error', sprintf( __( 'Uploaded file must be %s', 'wp-import-export' ), Helper::arrTostr( Helper::getSupportedExt() ) ) );
                        }
                        Settings::setOption( 'uploder/method', "local" );
                        Settings::set( "file", $name );
                } elseif ( Settings::get( "file" ) !== $name ) {
                        return new \WP_Error( 'wpie_import_error', __( 'File Mismatch. Please Try Again', 'wp-import-export' ) );
                }


                $tempName = pathinfo( $name, PATHINFO_FILENAME ) . "_" . $chunk . ".part";

                $file = $dir . DIRECTORY_SEPARATOR . $tempName;

                $status = FileUploadManager::handleUpload( 'local-file', $file );

                if ( \is_wp_error( $status ) ) {
                        return $status;
                }

                return true;
        }

        
        public static function mergeChunks() {

                $dir = Settings::createImportDir( 'temp' );

                $filedir = Settings::createImportDir( 'upload' );

                if ( false === $dir ) {
                        return new \WP_Error( 'wpie_import_error', __( 'Failed to Crate Directory', 'wp-import-export' ) );
                }

                $name = Settings::get( "file" );

                $fileName = pathinfo( $name, PATHINFO_FILENAME );

                $file = $filedir . DIRECTORY_SEPARATOR . $name;

                $isError = null;

                $chunk = 1;

                $fp = Helper::fOpen( $file, "wb" );

                if ( \is_wp_error( $fp ) ) {
                        return $fp;
                }

                while ( file_exists( $dir . DIRECTORY_SEPARATOR . $fileName . "_" . $chunk . ".part" ) ) {

                        $fpart = Helper::fOpen( $dir . DIRECTORY_SEPARATOR . $fileName . "_" . $chunk . ".part", "rb" );

                        if ( is_wp_error( $fpart ) ) {
                                $isError = $fpart;
                                break;
                        }

                        while ( $buff = fread( $fpart, 4096 ) ) {
                                fwrite( $fp, $buff );
                        }

                        fclose( $fpart );

                        Helper::deleteFile( $dir . DIRECTORY_SEPARATOR . $fileName . "_" . $chunk . ".part" );

                        $chunk++;
                }

                fclose( $fp );

                if ( is_wp_error( $isError ) ) {
                        return $isError;
                }

                return true;
        }
}
