<?php



namespace WpieApp\Modules\Import\Controller\Items\Base;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\File\Record;

defined( 'WPIE__FILE__' ) || exit;


class DataCenter {

        
        private static $key;

        
        private static $id;

        
        private static $isNewItem;

        
        private static $item;

        
        private static $fields = [];

        
        private static $updateFieldList = [];

        
        private static $data = [];

        
        private static $dataKeys = [];

        
        private static $cache = [];

        
        private static $reader = null;

        
        public static function init() {

                $reader = self::setReader();

                if ( \is_wp_error( $reader ) ) {
                        return $reader;
                }

                self::$fields = Settings::getOption( "fields" );

                self::$updateFieldList = Settings::getOption( "can-update" );
        }

        
        public static function get( $field = "" ) {

                if ( !Helper::isNonEmptyStr( $field ) ) {
                        return "";
                }

                if ( !isset( self::$cache[ $field ] ) ) {
                        self::$cache[ $field ] = self::getData( $field );
                }

                return self::$cache[ $field ];
        }

        
        public static function getFieldSetting( $field = "" ) {

                if ( !Helper::isNonEmptyStr( $field ) ) {
                        return "";
                }

                $parts = Helper::strToArr( $field, '/' );

                $data = self::$fields;

                foreach ( $parts as $part ) {

                        if ( isset( $data[ $part ] ) ) {
                                $data = $data[ $part ];
                        } else {
                                $data = null;
                                break;
                        }
                }

                return ( "as_specified" === $data ) ? self::getFieldSetting( $field . "_as_specified" ) : $data;
        }

        
        public static function getData( $field = "" ) {

                return self::getFileData( self::getFieldSetting( $field ) );
        }

        
        public static function getFileData( $field = "" ) {

                if ( !Helper::isNonEmptyStr( $field ) || strpos( $field, "{" ) === false || strpos( $field, "}" ) === false ) {
                        return Helper::toUtf8( $field );
                }

                $field = str_replace( self::$dataKeys, self::$data, $field );

                //remove extra variable in {} brekets
                if ( strpos( $field, "{" ) !== false && strpos( $field, "}" ) !== false ) {
                        $field = preg_replace( "/\{[A-Za-z0-9_-]{1,70}\}/i", "", $field );
                }

                return Helper::toUtf8( trim( $field ) );
        }

        
        public static function setId( $id = 0 ) {

                if ( Helper::toInt( $id ) < 1 ) {
                        return;
                }

                if ( self::$id > 0 ) {
                        return;
                }

                self::$id = Helper::toInt( $id );
        }

        
        public static function getId() {

                return self::$id;
        }

        
        public static function getKey() {

                return self::$key;
        }

        
        public static function setNewItem( $isNewItem ) {

                if ( !is_bool( $isNewItem ) ) {
                        return;
                }

                if ( !is_null( self::$isNewItem ) ) {
                        return;
                }

                self::$isNewItem = $isNewItem;
        }

        
        public static function isNewItem() {
                return self::$isNewItem;
        }

        
        public static function setItem( $item ) {

                if ( Helper::isEmpty( $item ) ) {
                        return;
                }

                if ( !Helper::isEmpty( self::$item ) ) {
                        return;
                }

                self::$item = $item;
        }

        
        public static function getItem() {

                return self::$item;
        }

        
        private static function setReader() {

                if ( self::$reader !== null ) {
                        return true;
                }

                self::$reader = Record::getReader();

                if ( \is_wp_error( self::$reader ) ) {
                        return self::$reader;
                }

                self::$reader->goToRow( Settings::getLog( "processed" ) + 1 );

                return self::setData();
        }

        
        private static function setData() {

                $data = self::$reader->current();

                if ( $data === false ) {
                        return false;
                }

                self::$key = Helper::randStr( 'import-' );

                self::$data = array_values( $data );

                self::$dataKeys = array_map( function ( $string ) {
                        return "{" . $string . "}";
                }, array_keys( $data ) );

                unset( $data );

                return true;
        }

        
        public static function next() {

                if ( !self::$reader->nextData() ) {
                        return false;
                }

                return self::setData();
        }

        
        public static function canUpdate( $field = "" ) {

                if ( !Helper::isNonEmptyStr( $field ) ) {
                        return false;
                }

                $data = Helper::subArray( self::$updateFieldList, $field );

                return is_numeric( $data );
        }

        
        public static function updateList( $field = "" ) {

                if ( !Helper::isNonEmptyStr( $field ) ) {
                        return "";
                }

                return isset( self::$updateFieldList[ $field ] ) ? self::$updateFieldList[ $field ] : "";
        }

        
        public static function clear() {

                self::$id = 0;

                self::$item = null;

                self::$isNewItem = null;

                self::$cache = [];

                self::$dataKeys = [];
        }
}
