<?php



namespace WpieApp\Modules\Import\Controller\Items\Base\Filters;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;

defined( 'WPIE__FILE__' ) || exit;


class Base {

        
        private static $filter;

        
        private static $field;

        
        private static $where = [];

        
        private static $join = [];

        
        public static function addJoin( $join = null ) {

                if ( Helper::isEmptyStr( $join ) ) {
                        return;
                }

                self::$join[] = $join;
        }

        
        public static function addWhere( $where = null, $cause = "" ) {

                if ( $where === false ) {
                        self::$where[] = " 1 != 1 ";
                }
                if ( Helper::isEmptyStr( $where ) ) {
                        return;
                }
                if ( Helper::isEmptyStr( $cause ) ) {
                        $cause = self::addRuleSeparator();
                }

                $where = DB::removePlaceholder( $where );

                self::$where[] = " " . $cause . " ( " . $where . " ) ";
        }

        
        public static function getJoin() {
                return self::$join;
        }

        
        public static function getWhere() {
                return self::$where;
        }

        
        public static function init() {

                $filters = Settings::getOption( 'filters' );

                if ( !Helper::isNonEmptyArray( self::$filter ) || !Helper::isNonEmptyArray( $filters ) || !is_object( $filters ) ) {
                        return false;
                }

                foreach ( $filters as $filter ) {

                        self::addFilter( $filter );
                }
        }

        
        public static function addFilter( $filter = null ) {

                if ( Helper::isEmpty( $filter ) || !isset( $filter->field ) ) {
                        return;
                }

                self::$filter = $filter;

                self::$field = $filter->field;

                static::addRule();
        }

        
        public static function getOption( $option = "", $type = "filter", $default = "" ) {

                if ( Helper::isEmptyStr( $option ) ) {
                        return $default;
                }

                if ( $type === "field" ) {
                        return ( isset( self::$field->$option ) ? self::$field->$option : $default);
                }

                return ( isset( self::$filter->$option ) ? self::$filter->$option : $default);
        }

        
        public static function bulidRule( $isIntVal = false ) {

                $condition = self::getOption( 'condition' );

                $isDate = intval( self::getOption( 'isDate', 'field' ) ) === 1;

                $isDate = $isDate ? $isDate : self::getOption( 'dateCompare' );

                $value = self::getOption( 'value' );

                return RuleParser::bulidRule( $condition, $value, $isDate, $isIntVal );
        }

        
        public static function addRuleSeparator() {

                $separator = self::getOption( 'rule_separator' );

                if ( Helper::isNonEmptyStr( $separator ) ) {
                        return " " . $separator . " ";
                }
                return "";
        }

        
        public static function addDateQuery( $field = "" ) {


                if ( intval( self::getOption( "isDate", "field" ) ) === 1 || self::getOption( "dateCompare" ) === true ) {

                        return " DATE(" . $field . ") ";
                }

                return $field;
        }

}
