<?php



namespace WpieApp\Modules\Import\Controller\Items\Term;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Term\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Base\Engine as BaseEngine;
use WpieApp\Modules\Import\Controller\Items\Term\Engines\Standard;
use WpieApp\Modules\Import\Controller\Items\Term\Engines\Parents;
use WpieApp\Modules\Import\Controller\Items\Term\Engines\Meta;

defined( 'WPIE__FILE__' ) || exit;


class Engine extends BaseEngine {

        
        public static function import() {

                \do_action( "Wpie/Import/Term/Engine/Start" );

                if ( !static::insertTerm() ) {
                        return false;
                }
                
                static::afterAdd();

                static::updateTerm();

                \do_action( "Wpie/Import/Term/Engine/End" );

                return true;
        }
        
        
        protected static function afterAdd() {

                \do_action( "Wpie/Import/Term/Engine/Add/After" );
                
                parent::afterAdd();
        }

        
        protected static function prepareTerm() {

                $standard = Standard::get();

                $parents = Parents::get();

                return array_merge( $standard, $parents );
        }

        
        protected static function setItem( $id = 0 ) {

                $taxonomy = Settings::getTaxonomy();

                DataCenter::setId( $id );

                DataCenter::setItem( Search::getTerm( 'id', $id, $taxonomy ) );
        }

        
        protected static function updateTerm() {

                static::updateMeta();
        }

        
        protected static function updateMeta() {

                Meta::import();
        }

        
        protected static function insertTerm() {

                $data = \apply_filters( "Wpie/Import/Term/Import/Before", static::prepareTerm(), Settings::getTaxonomy() );

                $id = ( DataCenter::isNewItem() ? self::insert( $data ) : self::update( $data ));

                if ( false === $id ) {
                        return false;
                }

                if ( \is_wp_error( $id ) ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $id->get_error_message() );

                        return false;
                }

                if ( \absint( $id ) === 0 ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( "something wrong, ID = 0 was generated.", 'wp-import-export' ) );

                        return false;
                }

                static::setItem( $id );

                return true;
        }

        
        protected static function insert( $data = [] ) {

                if ( !isset( $data[ 'name' ] ) || !Helper::isNonEmptyStr( $data[ 'name' ] ) ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( "Cannot create a Term with an empty name.", 'wp-import-export' ) );
                        return false;
                }

                $taxonomy = Settings::getTaxonomy();

                if ( !Helper::isNonEmptyStr( $taxonomy ) ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( "invalid taxonomy", 'wp-import-export' ) );
                        return false;
                }

                $name = $data[ 'name' ];

                $term = \wp_insert_term( $name, $taxonomy, $data );

                if ( is_array( $term ) && isset( $term[ 'term_id' ] ) ) {
                        return $term[ 'term_id' ];
                }

                return $term;
        }

        
        protected static function update( $data = [] ) {

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return DataCenter::getId();
                }

                $termId = DataCenter::getId();

                $taxonomy = Settings::getTaxonomy();

                $result = \wp_update_term( $termId, $taxonomy, $data );

                if ( \is_wp_error( $result ) ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $result->get_error_message() );
                }

                return DataCenter::getId();
        }

        
        public static function searchDuplicates() {

                $taxonomy = Settings::getTaxonomy();

                if ( !Helper::isNonEmptyStr( $taxonomy ) ) {
                        return 0;
                }

                $searchMethod = DataCenter::get( "search/method" );

                $id = 0;

                switch ( $searchMethod ) {

                        case "name":
                        case "slug":
                                $field = DataCenter::get( "search/" . $searchMethod );

                                $field = Helper::isNonEmptyStr( $field ) ? $field : DataCenter::get( 'standard/' . $searchMethod . '/data' );

                                $id = Helper::isNonEmptyStr( $field ) ? Search::getTermIdBy( $searchMethod, $field, $taxonomy ) : 0;

                                break;
                        case "id":
                                $field = DataCenter::get( "search/id" );

                                $id = (Helper::isNonEmptyStr( $field ) && absint( $field ) > 0) ? Search::getTermIdBy( 'id', $field, $taxonomy ) : 0;

                                break;
                        case "meta":
                                $metaKey   = DataCenter::get( "search/meta/key" );
                                $metaValue = DataCenter::get( "search/meta/value" );

                                if ( Helper::isNonEmptyStr( $metaKey ) && Helper::isNonEmptyStr( $metaValue ) ) {
                                        $id = Search::getTermIdByMeta( $metaKey, $metaValue );
                                }
                                break;

                        default:
                                $id = AutoSearch::get();
                                break;
                }

                return $id;
        }
}
