<?php



namespace WpieApp\Modules\Import\Controller;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Base\Controller\Settings as SettingBase;

defined( 'WPIE__FILE__' ) || exit;


class Settings extends SettingBase {

        
        protected static $data = [];

        
        const IMPORT_FILE = "import";

        
        const FILTERED_FILE = "filtered";

        
        public static function autoLoad() {

                $id = Helper::toInt( Helper::_post( "id" ) );

                if ( $id > 0 ) {
                        static::load( $id );
                        return $id;
                }

                $settings = Helper::_post( "settings" );

                static::load( [ "options" => $settings ] );

                return static::save();
        }

        
        public static function findDuplicate() {

                $id = Settings::get( "id" );

                $file = Settings::get( "file" );

                return DB::wpdb()->get_var( DB::wpdb()->prepare( "SELECT `id` FROM " . DB::getPluginTable() . " where `id` != %d and `status` NOT IN ('draft','init') and process = 'import' and `process_type` = 'regular' and `file` = %s ORDER BY `id` DESC Limit 0,1", $id, $file ) );
        }

        
        public static function setContentType( $type = "" ) {

                if ( !Helper::isNonEmptyStr( $type ) ) {
                        return false;
                }

                $data = Helper::strToArr( $type, "/" );

                $category = (isset( $data[ 0 ] ) ? $data[ 0 ] : "");

                $contentType = (isset( $data[ 1 ] ) && Helper::isNonEmptyStr( $data[ 1 ] ) ? $data[ 1 ] : $category);

                Settings::set( [ "content_type" => $contentType, 'category' => $category ] );
        }

        
        public static function getFilePath() {

                $filteredFile = static::getFilteredFilePath();

                if ( file_exists( $filteredFile ) ) {
                        return $filteredFile;
                }

                return static::getImportFilePath();
        }

        
        public static function getImportFilePath() {

                return static::getCurrentDir( "file" ) . DIRECTORY_SEPARATOR . static::IMPORT_FILE . "." . static::getFileFormat();
        }

        
        public static function getFilteredFilePath() {

                return static::getCurrentDir( "file" ) . DIRECTORY_SEPARATOR . static::FILTERED_FILE . "." . static::getFileFormat();
        }

        
        public static function getUploadFilePath() {

                return static::getCurrentDir( "upload" ) . DIRECTORY_SEPARATOR . static::get( "file" );
        }

        
        public static function getFileFormat() {

                return ('xml' === static::getOption( "file/format" )) ? 'xml' : 'csv';
        }

        
        public static function getLogFilePath() {

                return Helper::pathJoin( static::getCurrentDir( 'log' ), 'debug.log' );
        }

        
        public static function getCurrentDir( $dir = "" ) {

                $filedir = parent::get( "filedir" );

                if ( !Helper::isNonEmptyStr( $filedir ) ) {
                        return false;
                }

                $importDir = Helper::pathJoin( WPIE_UPLOAD_IMPORT_DIR, $filedir );

                if ( !Helper::isNonEmptyStr( $dir ) ) {
                        return $importDir;
                }

                return Helper::pathJoin( $importDir, Helper::sanitizeKey( $dir ) );
        }

        
        public static function createImportDir( $dir = "" ) {

                if ( !Helper::isNonEmptyStr( $dir ) ) {
                        return false;
                }
                $path = static::getCurrentDir( $dir );

                if ( $path === false ) {
                        return false;
                }

                Helper::createDir( $path );

                return $path;
        }

        
        public static function getContentLabel() {

                $type = static::get( 'content_type' );

                $category = static::get( 'category' );

                $contentType = $category . '/' . $type;

                $dbContentType = static::getOption( 'Info/Content/Type' );

                $label = static::getOption( 'Info/Content/Label' );

                if ( $contentType !== $dbContentType || !Helper::isNonEmptyStr( $label ) ) {

                        $importTypes = Helper::getImpExptypes( $contentType );

                        $label = isset( $importTypes[ $contentType ] ) ? $importTypes[ $contentType ] : 'Posts';

                        if ( 0 < self::get( 'id' ) ) {
                                static::setOption( 'Info/Content/Type', $contentType );

                                static::setOption( 'Info/Content/Label', $label );
                        }
                }

                return $label;
        }
}
