<?php



namespace WpieApp\Modules\Import\View\FileSetup;

use WpieApp\Modules\Import\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Manager {

        
        public static function get() {

                
                return \apply_filters(
                        'Wpie/Modules/Import/View/FileSetup',
                        [
                                "class"      => "wpie-setup-file",
                                "groupClass" => "wpie-file-setup",
                                "order"      => 5,
                                "notes"      => self::getNotes(),
                                "blocks"     => self::getBlocks()
                        ]
                );
        }

        
        public static function getBlocks() {

                $blocks = [
                        "LocalUpload"  => LocalUpload::getBlocks(),
                        "URL"          => URL::getBlocks(),
                        "Reimport"     => Reimport::getBlocks(),
                        "ExistingFile" => ExistingFile::getBlocks(),
                ];

                if ( version_compare( \phpversion(), WPIE_VENDOR_PHP_VERSION, '>=' ) ) {
                        $blocks = array_merge( $blocks, [
                                "Ftp"                => Ftp::getBlocks(),
                                "Sftp"               => Sftp::getBlocks(),
                                "GoogleDrive"        => GoogleDrive::getBlocks(),
                                "Dropbox"            => Dropbox::getBlocks(),
                                "GoogleCloudStorage" => GoogleCloudStorage::getBlocks(),
                                ]
                        );
                }

                return $blocks;
        }

        
        public static function getNotes() {

                $fileExt = Helper::arrTostr( Helper::getSupportedFileExt(), ', ' );

                $compressExt = Helper::arrTostr( Helper::getSupportedCompressExt(), ', ' );

                $notes = [
                        [
                                "type"       => "primary",
                                "icon-class" => "fa-solid fa-circle-info ",
                                "class"      => 'me-3',
                                "text"       => __( 'Pick any one method to set up the file', 'wp-import-export' ),
                        ],
                        [
                                "type"       => "success",
                                "icon-class" => "fa-solid fa-circle-info ",
                                "class"      => 'me-3',
                                "text"       => __( 'Supported File Formats :', 'wp-import-export' ) . " " . $fileExt,
                        ],
                        [
                                "type"       => "success",
                                "icon-class" => "fa-solid fa-circle-info ",
                                "class"      => 'me-3',
                                "text"       => __( 'Supported Compress File Formats', 'wp-import-export' ) . " : " . $compressExt,
                        ],
                        [
                                "type"       => "success",
                                "icon-class" => "fa-solid fa-circle-info ",
                                "class"      => 'me-3',
                                "text"       => __( 'CSV or XML formats are recommended for the best performance during import', 'wp-import-export' ),
                        ],
                ];

                if ( WPIE_PRO && version_compare( \phpversion(), WPIE_VENDOR_PHP_VERSION, '<' ) ) {
                        $notes[] = [
                                "type"       => "danger",
                                "icon-class" => "fa-solid fa-circle-info ",
                                "class"      => 'me-3',
                                /* translators: %s: PHP version */
                                "text"       => sprintf( __( 'To access FTP, SFTP, Dropbox, Google Drive, and Google Cloud file setup options, please upgrade to PHP version %s or higher', 'wp-import-export' ), WPIE_VENDOR_PHP_VERSION ),
                        ];
                }
                
                return \apply_filters( 'Wpie/Modules/Import/View/FileSetup/Notes', $notes );
        }
}
