<?php



namespace WpieApp\Providers;

use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Assets {

        
        Private static $styles = [];

        
        Private static $scripts = [];

        
        const DEFAULT_HANDLE = Helper::PLUGIN_PREFIX . 'admin';

        
        const GLOBAL_HANDLE = Helper::PLUGIN_PREFIX . 'global';

        
        public static function enqueue() {

                $activeModule = Helper::getActiveModule();

                if ( Helper::isNonEmptyStr( $activeModule ) ) {

                        // Add Plugin Common Script & Style
                        self::addCommonStyles();
                        self::addCommonScripts();
                }

                // Enqueue Style
                self::enqueueStyles();

                // Enqueue Script
                self::enqueueScripts();

                //Render Extra Json Data
                self::renderJson();

                
                \do_action( 'Wpie/Enqueue/Assets' );
        }

        
        public static function setData( $data = [] ) {

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        $data = [];
                }

                self::$scripts = isset( $data[ 'scripts' ] ) ? $data[ 'scripts' ] : [];

                self::$styles = isset( $data[ 'styles' ] ) ? $data[ 'styles' ] : [];

                self::enqueueDefault();
        }

        
        public static function enqueueDefault() {

                self::$styles = array_replace( self::$styles, self::getGlobalStyles() );

                self::$scripts = array_replace( self::$scripts, self::getGlobalScripts() );

                //Enqueue Assests
                \add_action( 'admin_enqueue_scripts', [ __CLASS__, 'enqueue' ] );
        }

        
        private static function addCommonScripts() {

                self::$scripts[ 'jquery' ] = "";

                self::$scripts[ self::DEFAULT_HANDLE ] = [
                        "src"      => WPIE_ASSETS_URL . '/js/admin.js',
                        "deps"     => [ 'jquery' ],
                        "register" => true
                ];
                self::$scripts[ 'wpie-bootstrap' ]     = [
                        "src" => WPIE_ASSETS_URL . '/js/bootstrap.js'
                ];
                self::$scripts[ 'wpie-select2' ]       = [
                        "src" => WPIE_ASSETS_URL . '/js/select2.js'
                ];
        }

        
        private static function addCommonStyles() {

                //Plugin default Fonts
                self::$styles[ 'wpie-font-poppins' ] = [
                        "src" => 'https://fonts.googleapis.com/css?family=Poppins:300,400,500,600,700&display=swap',
                ];

                self::$styles[ 'wpie-admin' ] = [
                        "src"      => WPIE_ASSETS_URL . '/css/admin.css',
                        "register" => true,
                        "rtl"      => true
                ];

                self::$styles[ 'wpie-fontawesome' ] = [
                        "src" => WPIE_ASSETS_URL . '/css/fontawesome.min.css',
                ];

                self::$styles[ 'wpie-bootstrap' ] = [
                        "src" => WPIE_ASSETS_URL . '/css/bootstrap.css',
                        "rtl" => true
                ];

                self::$styles[ 'wpie-bootstrap-extended' ] = [
                        "src" => WPIE_ASSETS_URL . '/css/bootstrap-extended.css',
                        "rtl" => true
                ];

                self::$styles[ 'wpie-select2' ] = [
                        "src" => WPIE_ASSETS_URL . '/css/select2.css',
                ];

                self::$styles[ 'wpie-select2-theme' ] = [
                        "src" => WPIE_ASSETS_URL . '/css/select2-bootstrap-5-theme.css',
                        "rtl" => true
                ];
        }

        
        private static function getGlobalStyles() {

                $styles = [];

                $styles[ 'wpie-global' ] = [
                        "src"      => WPIE_ASSETS_URL . '/css/global.css',
                        "register" => true,
                ];

                return $styles;
        }

        
        private static function getGlobalScripts() {

                $scripts = [];

                $scripts[ self::GLOBAL_HANDLE ] = [
                        "src"      => WPIE_ASSETS_URL . '/js/global.js',
                        "deps"     => [ 'jquery' ],
                        "register" => true
                ];

                return $scripts;
        }

        
        private static function enqueueStyles() {

                self::$styles = \apply_filters( 'Wpie/Enqueue/Styles', self::$styles );

                if ( !Helper::isNonEmptyArray( self::$styles ) ) {
                        return;
                }

                foreach ( self::$styles as $handle => $data ) {

                        $register = false;

                        if ( is_array( $data ) ) {
                                $src      = isset( $data[ 'src' ] ) ? $data[ 'src' ] : "";
                                $deps     = isset( $data[ 'deps' ] ) ? $data[ 'deps' ] : null;
                                $register = isset( $data[ 'register' ] ) ? $data[ 'register' ] : false;
                        } else {
                                $src  = $data;
                                $deps = null;
                        }

                        if ( $register === true ) {
                                \wp_register_style( $handle, $src, $deps, WPIE_VERSION );
                                $src  = "";
                                $deps = null;
                        }

                        \wp_enqueue_style( $handle, $src, $deps, WPIE_VERSION );

                        if ( isset( $data[ 'rtl' ] ) && $data[ 'rtl' ] === true ) {
                                \wp_style_add_data( $handle, 'rtl', 'replace' );
                        }
                }
        }

        
        private static function enqueueScripts() {

                self::$scripts = \apply_filters( 'Wpie/Enqueue/Scripts', self::$scripts );

                if ( !Helper::isNonEmptyArray( self::$scripts ) ) {
                        return;
                }

                foreach ( self::$scripts as $handle => $data ) {

                        $register = false;
                        if ( is_array( $data ) ) {
                                $src      = isset( $data[ 'src' ] ) ? $data[ 'src' ] : "";
                                $deps     = isset( $data[ 'deps' ] ) ? $data[ 'deps' ] : null;
                                $register = isset( $data[ 'register' ] ) ? $data[ 'register' ] : false;
                        } else {
                                $src  = $data;
                                $deps = null;
                        }

                        if ( $register === true ) {
                                \wp_register_script( $handle, $src, $deps, WPIE_VERSION, [ 'in_footer' => true ] );
                                $src  = "";
                                $deps = null;
                        }

                        \wp_enqueue_script( $handle, $src, $deps, WPIE_VERSION, true );
                }
        }

        
        private static function renderJson() {

                \wp_localize_script( self::DEFAULT_HANDLE, JsonManager::OBJECT_NAME, JsonManager::getData() );

                \wp_localize_script( self::GLOBAL_HANDLE, JsonManager::GLOBAL_OBJECT_NAME, JsonManager::getGlobals() );
        }
}
